%  Interpolate Glosea5 data to ROMS model open boundaries 
%  Ross sea and Amundsen Sea Model (RAS)
%  Written by Xie Chuan
%  Create date: 2021-9-10
%
clear all; 
close all; 
clc;

%-------------------------------------------------------------------------------
%--------------------------- generate Glosea5 data -----------------------------
%-------------------------------------------------------------------------------
Year=['1998';'1999';'2000';'2001';'2002';'2003';'2004';'2005';'2006';'2007';'2008';...
    '2009';'2010';'2011';'2012';'2013';'2014';'2015';'2016';'2017';'2018';'2019'];
Month=['01';'02';'03';'04';'05';'06';'07';'08';'09';'10';'11';'12'];
days=['01';'02';'03';'04';'05';'06';'07';'08';'09';'10';'11';'12';'13';'14';'15';
    '16';'17';'18';'19';'20';'21';'22';'23';'24';'25';'26';'27';'28';'29';'30';'31'];
Monthabb=['Jan';'Feb';'Mar';'Apr';'May';'Jun';'Jul';'Aug';'Sep';'Oct';'Nov';'Dec'];
% Common parameters
mybasedate = datenum(2003,1,1);

for iyear=6:22
   for jmonth=1:12
       %Determine whether it is a leap year
       if iyear==3||iyear==7||iyear==11||iyear==15||iyear==19
            Monthdays=[31;29;31;30;31;30;31;31;30;31;30;31];   %
       else
            Monthdays=[31;28;31;30;31;30;31;31;30;31;30;31];   %
       end
       load(['..\Ross_amundsen_roms_model\boundary_file\A2_AMSR_sic_rawdata\sic_',Year(iyear,:),'_glosea5grid.mat']);
       varname_sic=['sic_',Year(iyear,:)];
       sic_year=eval(varname_sic);
       filename_a=['..\Ross_amundsen_roms_model\boundary_file\A1_Glosea5_rawdata\'...
           ,Year(iyear,:),'\Glosea5_',Year(iyear,:),Month(jmonth,:),'_a.nc'];
       filename_b=['..\Ross_amundsen_roms_model\boundary_file\A1_Glosea5_rawdata\'...
           ,Year(iyear,:),'\Glosea5_',Year(iyear,:),Month(jmonth,:),'_b.nc'];
       salinity=ncread(filename_a,'so_foam');
       temp=ncread(filename_a,'thetao_foam');
       u=ncread(filename_b,'uo_foam');
       v=ncread(filename_b,'vo_foam');
       %Change the number of layers to 1:72
       salinity=salinity(:,:,1:72,:);
       temp=temp(:,:,1:72,:);
       u=u(:,:,1:72,:);
       v=v(:,:,1:72,:);
       %
       ssh=ncread(filename_b,'zos_foam');
       num_days=Monthdays(jmonth);
       for kdays=1:num_days    
           ts(kdays,:)=[days(kdays,:),'-',Monthabb(jmonth,:),'-',Year(iyear,:)];
           td(kdays,:)=datenum(ts(kdays,:))-mybasedate;
       end
       % load sea ice concentration data
       day_start=sum(Monthdays(1:jmonth-1,:))+1;
       day_final=sum(Monthdays(1:jmonth,:));
       sic=sic_year(:,:,day_start:day_final)./100;    %Sea ice density conversion [0-1]
       filename_total=['..\Ross_amundsen_roms_model\boundary_file\B_Boundary_variables_interpolate_output\Glosea5_'...
           ,Year(iyear,:),Month(jmonth,:),'.mat'];
       save(filename_total,'salinity','temp','u','v','sic','ssh','ts','td');
       clear ts td;
       disp(['Processing : ',Year(iyear,:),Month(jmonth,:),' ... ']);
   end
end


depth=depth(1:72,:);
save('Glosea5_grid_ross.mat','depth','Glosea5_mask','lat_Glosea5','lon_Glosea5');

%%
% -------------------------------------------------------------------------
% ------------------------- user settings ---------------------------------
% -------------------------------------------------------------------------
%
% ------ input/output ------
%
clc;
clear all;

casename='RAS';
glosea5_data_path='..\Ross_amundsen_roms_model\boundary_file\B_Boundary_variables_interpolate_output\'; % path of data file 
glosea5_grid_path='..\Ross_amundsen_roms_model\boundary_file\A1_Glosea5_rawdata\Grid\'; % path of Glosea5 grid data file 
outdata_path='..\Ross_amundsen_roms_model\boundary_file\C_RAS_model_boundary_files\32layer\'; % path of data file 
ROMS_grid_path='..\Ross_amundsen_roms_model\grid_file\'; % path of ROMS grid 
% ----------------------------- input file --------------------------------
ROMS_grid=[ROMS_grid_path casename '_grd_32layer_new.nc']; % ROMS grid file
Glosea5_grid=[glosea5_grid_path 'Glosea5_grid_ross.mat'];
%----------------------------------------------------------------------------------
% --- output file ---
% outfile=[data_path casename '_bry_data.mat']; % output file name
%
% ------------- define time period ------------
data_year = 2017;  % start year   
nf=12;
%---------------------------------------------------------------------------------
%
% --- data file ---
datafile=[];
outfile=[]; % output file name
for ik=1:nf
    if ik < 10
        tk=[num2str(0)  num2str(ik)];
    elseif ik > 9 && ik < 100
        tk=[ num2str(ik)];
    else
        tk=num2str(ik);
    end
    datafile0=[glosea5_data_path 'Glosea5_' num2str(data_year) tk '.mat'];
    datafile=[datafile;datafile0];
    outfile0=[outdata_path casename '_bry_data_' num2str(data_year) tk '.mat']; % output file name
    outfile=[outfile;outfile0];
end

% ------------------ S-coordinate setup ------------------
%
N = 32;           % No. of vertical layers
Vtransform = 2;   % Vertical transformation equation: 1, original; 2, new
Vstretching = 4;  % Vstretching   Vertical stretching function:
%                    Vstretching = 1,  original (Song and Haidvogel, 1994)
%                    Vstretching = 2,  A. Shchepetkin (UCLA-ROMS, 2005)
%                    Vstretching = 3,  R. Geyer BBL refinement
%                    Vstretching = 4,  A. Shchepetkin (UCLA-ROMS, 2010)
theta_s = 4;      % S-coordinate surface control parameter (scalar)
theta_b = 2;      % S-coordinate bottom control parameter (scalar)
hc = 200;          % Width (m) of surface or bottom boundary layer in which
                  %  higher vertical resolution is required during
                  %  stretching (scalar)
igrid = 0;        % Depth grid type logical switch:
%                   igrid=1  => density points
%                   igrid=2  => streamfunction points
%                   igrid=3  => u-velocity points
%                   igrid=4  => v-velocity points
%                   igrid=5  => w-velocity points
% 
% --- select open boundaries (by true/false) ---
obc_east=true;
obc_west=true;
obc_north=true;
obc_south=false;
%
% -------------------------------------------------------------------------
% ------------------------------ load data --------------------------------
% -------------------------------------------------------------------------
disp('  Loading grid data ...');
% --- RHO grid ---
lon_rho=ncread(ROMS_grid,'lon_rho')';
lat_rho=ncread(ROMS_grid,'lat_rho')';
mask_rho=ncread(ROMS_grid,'mask_rho')';

% --- u grid ---
lon_u=ncread(ROMS_grid,'lon_u')';
lat_u=ncread(ROMS_grid,'lat_u')';
mask_u=ncread(ROMS_grid,'mask_u')';

% --- v grid ---
lon_v=ncread(ROMS_grid,'lon_v')';
lat_v=ncread(ROMS_grid,'lat_v')';
mask_v=ncread(ROMS_grid,'mask_v')';

% --- angle ---
ang = ncread(ROMS_grid,'angle')';

% --- depth ---
h = ncread(ROMS_grid,'h');

% --- ice shelf ---
zice = ncread(ROMS_grid,'zice');
zeta_iceshelf = zice;  

% --- grid dimensions ---
[Mp Lp]=size(lon_rho);   % Number of exterior RHO-points (Lp -> I, Mp -> J);
Lm=Lp-2;                 % Number of I-direction INTERIOR RHO-points
Mm=Mp-2;                 % Number of J-direction INTERIOR RHO-points
L = Lp-1;
M = Mp-1;

% -------------------------------------------------------------------------
% ------------------- z level calculation (Consider the effects of the ice shelf)---
% -------------------------------------------------------------------------
disp('  Calculating z level ...');

% for rho points
igrid=1; 
zr=set_depth(Vtransform,Vstretching,theta_s,theta_b,hc,N,igrid,h,zeta_iceshelf,0);
zr=permute(zr,[3,2,1]); % rearrange dimensions 
 % for u points
igrid=3;
zu=set_depth(Vtransform,Vstretching,theta_s,theta_b,hc,N,igrid,h,zeta_iceshelf,0);
zu=permute(zu,[3,2,1]); % rearrange dimensions 
% for v points
igrid=4; 
zv=set_depth(Vtransform,Vstretching,theta_s,theta_b,hc,N,igrid,h,zeta_iceshelf,0);
zv=permute(zv,[3,2,1]); % rearrange dimensions 
% for w points
igrid=5; 
zw=set_depth(Vtransform,Vstretching,theta_s,theta_b,hc,N,igrid,h,zeta_iceshelf,0);
zw=permute(zw,[3,2,1]); % rearrange dimensions 
%
h=h';
% -------------------------------------------------------------------------
% ------------------------ Generate boundary data -------------------------
% -------------------------------------------------------------------------
disp(' Gernerating boundary data ...');
%
% ----------- load data ------------
%
load(Glosea5_grid);
lons=lon_Glosea5';
lats=lat_Glosea5';

for fk=1:12
     disp(['    => Processing boundary data file ' num2str(fk) ' of ' num2str(nf)]);
     load(datafile(fk,:));
     salts=salinity; clear salinity;
     temps=temp; clear temp;
     sics=sic; clear sic;
     sshs=ssh; clear ssh;
     us=u; clear u;
     vs=v; clear v;
     
     salts=permute(salts,[4 3 2 1]);
     temps=permute(temps,[4 3 2 1]);
     sics=permute(sics,[3 2 1]);
     sshs=permute(sshs,[3 2 1]);
     us=permute(us,[4 3 2 1]);
     vs=permute(vs,[4 3 2 1]);
%
     sd=-1*flipud(depth);    % flip depth and change sign
%
     time_date=td; % date of data
     tt=time_date;
%
     [nt nz ny nx]=size(salts);   % size of data
% 
     lon_data=reshape(lons,nx*ny,1);  % change lon and lat to 1-D array
     lat_data=reshape(lats,nx*ny,1);
%
% np=9; % NO. of nearest data points that used to interpolate NaN data
% 
     if obc_east
        zeta_east=[];
        salt_east=[];
        temp_east=[];
        aice_east=[];
        u_east=[];
        v_east=[];
     end

     if obc_west
        zeta_west=[];
        salt_west=[];
        temp_west=[];
        aice_west=[];
        u_west=[];
        v_west=[];
     end

     if obc_north
        zeta_north=[];
        salt_north=[];
        temp_north=[];
        aice_north=[];
        u_north=[];
        v_north=[];
     end

     if obc_south
        zeta_south=[];
        salt_south=[];
        temp_south=[];
        aice_south=[];
        u_south=[];
        v_south=[];
     end
%
% --------- interpolation ---------
     disp('      -> Interpolating boundary ...');

     for tk=1:nt
        disp(['        : Time step ' num2str(tk) ' of ' num2str(nt)]);
    %
% -------- water surface level ---------
        tem0=squeeze(sshs(tk,:,:));
        tem0=reshape(tem0,nx*ny,1);
        tem=[lon_data,lat_data,tem0]; % combine location and data together
        % remove NaN
        kk=find(isnan(sum(tem')));
        tem(kk,:)=[]; 
        tem=double(tem);
        % - interpolaation -
        F = scatteredInterpolant(tem(:,1),tem(:,2),tem(:,3),'linear','nearest');
        % --- eastern boundary ---
        if obc_east
            obc_lon=lon_rho(:,end);
            obc_lat=lat_rho(:,end);
            obc_mask=mask_rho(:,end);
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            zeta_east(tk,:)=temi;
        end
        % - western boundary -
        if obc_west
            obc_lon=lon_rho(:,1);
            obc_lat=lat_rho(:,1);
            obc_mask=mask_rho(:,1);
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            zeta_west(tk,:)=temi;
        end
        % - northern boundary -
        if obc_north
            obc_lon=lon_rho(end,:)';
            obc_lat=lat_rho(end,:)';
            obc_mask=mask_rho(end,:)';
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            zeta_north(tk,:)=temi;
        end
        % - southern boundary -
        if obc_south
            obc_lon=lon_rho(1,:)';
            obc_lat=lat_rho(1,:)';
            obc_mask=mask_rho(1,:)';
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            zeta_south(tk,:)=temi;
        end     
%        
% -------- sea ice concentration ---------
        tem0=squeeze(sics(tk,:,:));
        tem0=reshape(tem0,nx*ny,1);
        tem=[lon_data,lat_data,tem0]; % combine location and data together
        % remove NaN
        kk=find(isnan(sum(tem')));
        tem(kk,:)=[]; 
        tem=double(tem);
        % - interpolaation -
        F = scatteredInterpolant(tem(:,1),tem(:,2),tem(:,3),'linear','nearest');
        % --- eastern boundary ---
        if obc_east
            obc_lon=lon_rho(:,end);
            obc_lat=lat_rho(:,end);
            obc_mask=mask_rho(:,end);
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            aice_east(tk,:)=temi;
        end
        % - western boundary -
        if obc_west
            obc_lon=lon_rho(:,1);
            obc_lat=lat_rho(:,1);
            obc_mask=mask_rho(:,1);
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            aice_west(tk,:)=temi;
        end
        % - northern boundary -
        if obc_north
            obc_lon=lon_rho(end,:)';
            obc_lat=lat_rho(end,:)';
            obc_mask=mask_rho(end,:)';
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            aice_north(tk,:)=temi;
        end
        % - southern boundary -
        if obc_south
            obc_lon=lon_rho(1,:)';
            obc_lat=lat_rho(1,:)';
            obc_mask=mask_rho(1,:)';
            temi=F(obc_lon,obc_lat); % interpolation
            % - replace land with the nearest point data -
            % find land/water cells
            idx_land=find(obc_mask < 0.5);
            idx_water=find(obc_mask > 0.5);
            % find water data at obc
            obc_lon1=obc_lon(idx_water);
            obc_lat1=obc_lat(idx_water);
            temi1=temi(idx_water);
            % find land data at obc
            obc_lon2=obc_lon(idx_land);
            obc_lat2=obc_lat(idx_land);
            % interpolate land with nearest data
            FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
            temi2=FN(obc_lon2,obc_lat2);
            % fill back to obc data
            temi(idx_land)=temi2; 
            aice_south(tk,:)=temi;
        end     
%        
% -------- temperature and salinity interpolation ---------
        disp('           * Temperature and Salinity ...');
        % ----- horizontal interpolation -----
            
        for zk=1:nz
            % ===== salinity =====
            tem0=squeeze(salts(tk,zk,:,:));
            tem0=reshape(tem0,nx*ny,1);
            tem=[lon_data,lat_data,tem0]; % combine location and data together
            % remove NaN
            kk=find(isnan(sum(tem')));
            tem(kk,:)=[]; 
            tem=double(tem);            
            % - interpolaation -
            F = scatteredInterpolant(tem(:,1),tem(:,2),tem(:,3),'linear','nearest');
            % --- eastern boundary ---
            if obc_east
                obc_lon=lon_rho(:,end);
                obc_lat=lat_rho(:,end);
                obc_mask=mask_rho(:,end);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obcer
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                salt_east0(zk,:)=temi;
            end
            % - western boundary -
            if obc_west
                obc_lon=lon_rho(:,1);
                obc_lat=lat_rho(:,1);
                obc_mask=mask_rho(:,1);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                salt_west0(zk,:)=temi;
            end
            % - northern boundary -
            if obc_north
                obc_lon=lon_rho(end,:)';
                obc_lat=lat_rho(end,:)';
                obc_mask=mask_rho(end,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                salt_north0(zk,:)=temi;
            end
            % - southern boundary -
            if obc_south
                obc_lon=lon_rho(1,:)';
                obc_lat=lat_rho(1,:)';
                obc_mask=mask_rho(1,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                salt_south0(zk,:)=temi;
            end
        
            % ===== temperature =====
            tem0=squeeze(temps(tk,zk,:,:));
            tem0=reshape(tem0,nx*ny,1);
            tem=[lon_data,lat_data,tem0]; % combine location and data together
            % remove NaN
            kk=find(isnan(sum(tem')));
            tem(kk,:)=[]; 
            tem=double(tem);
            % - interpolaation -
            F = scatteredInterpolant(tem(:,1),tem(:,2),tem(:,3),'linear','nearest');
            % - eastern boundary -
            if obc_east
                obc_lon=lon_rho(:,end);
                obc_lat=lat_rho(:,end);
                obc_mask=mask_rho(:,end);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                temp_east0(zk,:)=temi;
            end
            % - western boundary -
            if obc_west
                obc_lon=lon_rho(:,1);
                obc_lat=lat_rho(:,1);
                obc_mask=mask_rho(:,1);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                temp_west0(zk,:)=temi;
            end
            % - northern boundary -
            if obc_north
                obc_lon=lon_rho(end,:)';
                obc_lat=lat_rho(end,:)';
                obc_mask=mask_rho(end,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                temp_north0(zk,:)=temi;
            end
            % - southern boundary -
            if obc_south
                obc_lon=lon_rho(1,:)';
                obc_lat=lat_rho(1,:)';
                obc_mask=mask_rho(1,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                temp_south0(zk,:)=temi;
            end
        end
        %
        % -------- vertical interpolation --------
        % --- Eastern boundary ---
        if obc_east
            z0=squeeze(zr(:,:,end)); % depth at the boundary
            salt_east(tk,:,:)=zeros(N,Mp);
            temp_east(tk,:,:)=zeros(N,Mp);
            obc_mask=mask_rho(:,end);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                % === salinity ===
                tem1=salt_east0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                salt_east(tk,:,ik)=temi;
                % === temperature ===
                tem1=temp_east0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                temp_east(tk,:,ik)=temi;
            end
        end
    %
        % ------ Western boundary ------
        if obc_west
            z0=squeeze(zr(:,:,1)); % depth at the boundary
            salt_west(tk,:,:)=zeros(N,Mp);
            temp_west(tk,:,:)=zeros(N,Mp);
            obc_mask=mask_rho(:,1);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                % === salinity ===
                tem1=salt_west0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                salt_west(tk,:,ik)=temi;
                % === temperature ===
                tem1=temp_west0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                temp_west(tk,:,ik)=temi;
            end
        end
    
        % --- Northern boundary ---
        if obc_north
            z0=squeeze(zr(:,end,:)); % depth at the boundary
            salt_north(tk,:,:)=zeros(N,Lp);
            temp_north(tk,:,:)=zeros(N,Lp);
            obc_mask=mask_rho(end,:);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                % === salinity ===
                tem1=salt_north0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                salt_north(tk,:,ik)=temi;
                % === temperature ===
                tem1=temp_north0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                temp_north(tk,:,ik)=temi;
            end
        end
        
        % --- Southern boundary ---
        if obc_south
            z0=squeeze(zr(:,1,:)); % depth at the boundary
            salt_south(tk,:,:)=zeros(N,Lp);
            temp_south(tk,:,:)=zeros(N,Lp);
            obc_mask=mask_rho(1,:);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                % === salinity ===
                tem1=salt_south0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                salt_south(tk,:,ik)=temi;
                % === temperature ===
                tem1=temp_south0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                temp_south(tk,:,ik)=temi;
            end
        end
%        
% ---------------------- u  ---------------------
    %
        disp(['           * u ...']);
    % ------ horizontal interpolation ------
        for zk=1:nz
            tem0=squeeze(us(tk,zk,:,:));
            tem0=reshape(tem0,nx*ny,1);
            tem=[lon_data,lat_data,tem0]; % combine location and data together
            % remove NaN
            kk=find(isnan(sum(tem')));
            tem(kk,:)=[]; 
            tem=double(tem);
            % - interpolaation -
            F = scatteredInterpolant(tem(:,1),tem(:,2),tem(:,3),'linear','nearest');
            % - eastern boundary -
            if obc_east
                obc_lon=lon_u(:,end);
                obc_lat=lat_u(:,end);
                obc_mask=mask_u(:,end);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                u_east0(zk,:)=temi;
            end
            % - western boundary -
            if obc_west
                obc_lon=lon_u(:,1);
                obc_lat=lat_u(:,1);
                obc_mask=mask_u(:,1);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                u_west0(zk,:)=temi;
            end
            % - northern boundary -
            if obc_north
                obc_lon=lon_u(end,:)';
                obc_lat=lat_u(end,:)';
                obc_mask=mask_u(end,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                u_north0(zk,:)=temi;
            end
            % - southern boundary -
            if obc_south
                obc_lon=lon_u(1,:)';
                obc_lat=lat_u(1,:)';
                obc_mask=mask_u(1,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                u_south0(zk,:)=temi;
            end
        end    
%        
    % ---------- vertical interpolation ------------
        % --- eastern boundary ---
        if obc_east
            z0=squeeze(zu(:,:,end)); % depth at the boundary
            u_east(tk,:,:)=zeros(N,Mp);
            obc_mask=mask_u(:,end);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=u_east0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                u_east(tk,:,ik)=temi;
            end
        end
    %
        % --- western boundary ---
        if obc_west
            z0=squeeze(zu(:,:,1)); % depth at the boundary
            u_west(tk,:,:)=zeros(N,Mp);
            obc_mask=mask_u(:,1);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=u_west0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                u_west(tk,:,ik)=temi;
            end
        end
    %
        %
        % --- northern boundary ---
        if obc_north
            z0=squeeze(zu(:,end,:)); % depth at theboundary
            u_north(tk,:,:)=zeros(N,L);
            obc_mask=mask_u(end,:);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=u_north0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                u_north(tk,:,ik)=temi;
            end
        end
       %
       % --- southern boundary ---
       if obc_south
            z0=squeeze(zu(:,1,:)); % depth at the boundary
            u_south(tk,:,:)=zeros(N,L);
            obc_mask=mask_u(1,:);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=u_south0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                u_south(tk,:,ik)=temi;
            end
        end

% ---------------------- v  ---------------------
    %
        disp(['           * v ...']);
    % ------ horizontal interpolation ------
        for zk=1:nz
            tem0=squeeze(vs(tk,zk,:,:));
            tem0=reshape(tem0,nx*ny,1);
            tem=[lon_data,lat_data,tem0]; % combine location and data together
            % remove NaN
            kk=find(isnan(sum(tem')));
            tem(kk,:)=[]; 
            tem=double(tem);
            % - interpolaation -
            F = scatteredInterpolant(tem(:,1),tem(:,2),tem(:,3),'linear','nearest');
            % - eastern boundary -
            if obc_east
                obc_lon=lon_v(:,end);
                obc_lat=lat_v(:,end);
                obc_mask=mask_v(:,end);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                v_east0(zk,:)=temi;
            end
            % - western boundary -
            if obc_west
                obc_lon=lon_v(:,1);
                obc_lat=lat_v(:,1);
                obc_mask=mask_v(:,1);
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                v_west0(zk,:)=temi;
            end
            % - northern boundary -
            if obc_north
                obc_lon=lon_v(end,:)';
                obc_lat=lat_v(end,:)';
                obc_mask=mask_v(end,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                v_north0(zk,:)=temi;
            end
            % - southern boundary -
            if obc_south
                obc_lon=lon_v(1,:)';
                obc_lat=lat_v(1,:)';
                obc_mask=mask_v(1,:)';
                temi=F(obc_lon,obc_lat); % interpolation
                % - replace land with the nearest point data -
                % find land/water cells
                idx_land=find(obc_mask < 0.5);
                idx_water=find(obc_mask > 0.5);
                % find water data at obc
                obc_lon1=obc_lon(idx_water);
                obc_lat1=obc_lat(idx_water);
                temi1=temi(idx_water);
                % find land data at obc
                obc_lon2=obc_lon(idx_land);
                obc_lat2=obc_lat(idx_land);
                % interpolate land with nearest data
                FN = scatteredInterpolant(obc_lon1,obc_lat1,temi1,'nearest','nearest');
                temi2=FN(obc_lon2,obc_lat2);
                % fill back to obc data
                temi(idx_land)=temi2; 
                v_south0(zk,:)=temi;
            end
        end    
%        
    % ---------- vertical interpolation ------------
        % --- eastern boundary ---
        if obc_east
            z0=squeeze(zv(:,:,end)); % depth at the boundary
            v_east(tk,:,:)=zeros(N,M);
           obc_mask=mask_v(:,end);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=v_east0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                v_east(tk,:,ik)=temi;
            end
        end
    %
        % --- western boundary ---
        if obc_west
            z0=squeeze(zv(:,:,1)); % depth at the boundary
            v_west(tk,:,:)=zeros(N,M);
            obc_mask=mask_v(:,1);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=v_west0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                v_west(tk,:,ik)=temi;
            end
        end
    %
        %
        % --- northern boundary ---
        if obc_north
            z0=squeeze(zv(:,end,:)); % depth at theboundary
            v_north(tk,:,:)=zeros(N,Lp);
            obc_mask=mask_v(end,:);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=v_north0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                v_north(tk,:,ik)=temi;
            end
        end
       %
       % --- southern boundary ---
       if obc_south
            z0=squeeze(zv(:,1,:)); % depth at the boundary
            v_south(tk,:,:)=zeros(N,Lp);
            obc_mask=mask_v(1,:);
            idx_water=find(obc_mask==1);
            nwater=length(idx_water);
            for mk=1:nwater
                ik=idx_water(mk);
                zi=z0(:,ik);        % model depth
                tem1=v_south0(:,ik);  % data
                tem1=flipud(tem1);  % change data up down
                if sum(isnan(tem1)) > nz-1 % for grids without data, use 0 
                    temi=0*ones(N,1);
                else
                    kk=find(isnan(tem1));
                    tem1(kk)=[];
                    zz=sd; zz(kk)=[];
                    temi=interp1(zz,tem1,zi,'linear'); % linear interpolation
                    kk0=find(isnan(temi));  % find NaN for lower layer
                    if length(kk0) > 0
                       % replace NaN with the nearst data 
                       dkk0=diff(kk0);
                       if max(dkk0) > 1  % NaN at both surface and bottom
                           kkk=find(dkk0==max(dkk0));
                           kk1=kk0(1:kkk); % surface layer 
                           kk2=kk0(kkk+1:end); % bottom layer
                           temi(kk1)=temi(max(kk1)+1)*ones(size(kk1)); % for near bottom
                           temi(kk2)=temi(min(kk2)-1)*ones(size(kk2)); % for near surface 
                       else
                           if min(kk0) == 1
                              temi(kk0)=temi(max(kk0)+1)*ones(size(kk0)); % for near bottom
                           else
                              temi(kk0)=temi(min(kk0)-1)*ones(size(kk0)); % for near surface 
                           end
                       end
                    end
                end   
                v_south(tk,:,ik)=temi;
            end
        end
    end

    
% -------------------------------------------------------------------------
% --------------- Rotation of velocity (from E-N to XI-ETA) ---------------
% -------------------------------------------------------------------------
        disp('      -> Rotating velocity ...');
%
    % ------ eastern boundary ------
    if obc_east
        u_eastr=0*u_east; % define rotated velocities
        v_eastr=0*v_east;
        % - angle -
        ang0=ang(:,end);
        ang1=repmat(ang0',[N,1]);
        nrecord=size(u_east,1); % total number of data record
        for tk=1:nrecord
            ang2(tk,:,:)=ang1;
        end
        % - rotation interior -
        uin=u_east(:,:,2:end-1);
        vin=0.5*(v_east(:,:,1:end-1)+v_east(:,:,2:end));
        ur=uin.*cos(ang2(:,:,2:end-1))+vin.*sin(ang2(:,:,2:end-1));
        vr=vin.*cos(ang2(:,:,2:end-1))-uin.*sin(ang2(:,:,2:end-1));
        vrr=0.5*(vr(:,:,1:end-1)+vr(:,:,2:end));
        u_eastr(:,:,2:end-1)=ur;
        v_eastr(:,:,2:end-1)=vrr;
        % - add boundary points -
        ur1=uin(:,:,1).*cos(ang2(:,:,1))+vin(:,:,1).*sin(ang2(:,:,1));
        vr1=vin(:,:,1).*cos(ang2(:,:,1))-uin(:,:,1).*sin(ang2(:,:,1));
        u_eastr(:,:,1)=ur1;
        v_eastr(:,:,1)=vr1;
        ur2=uin(:,:,end).*cos(ang2(:,:,end))+vin(:,:,end).*sin(ang2(:,:,end));
        vr2=vin(:,:,end).*cos(ang2(:,:,end))-uin(:,:,end).*sin(ang2(:,:,end));
        u_eastr(:,:,end)=ur2;
        v_eastr(:,:,end)=vr2;
    end
    clear ang0 ang1 ang2 ur vr vrr ur1 vr1 ur2 vr2 uin vin;

    % --- western boundary ---
    if obc_west
        u_westr=0*u_west;
        v_westr=0*v_west;
        % - angle -
        ang0=ang(:,1);
        ang1=repmat(ang0',[N,1]);
        nrecord=size(u_west,1); % total number of data record
        for tk=1:nrecord
            ang2(tk,:,:)=ang1;
        end
        % - rotation interior -
        uin=u_west(:,:,2:end-1);
        vin=0.5*(v_west(:,:,1:end-1)+v_west(:,:,2:end));
        ur=uin.*cos(ang2(:,:,2:end-1))+vin.*sin(ang2(:,:,2:end-1));
        vr=vin.*cos(ang2(:,:,2:end-1))-uin.*sin(ang2(:,:,2:end-1));
        vrr=0.5*(vr(:,:,1:end-1)+vr(:,:,2:end));
        u_westr(:,:,2:end-1)=ur;
        v_westr(:,:,2:end-1)=vrr;
        % - add boundary points -
        ur1=uin(:,:,1).*cos(ang2(:,:,1))+vin(:,:,1).*sin(ang2(:,:,1));
        vr1=vin(:,:,1).*cos(ang2(:,:,1))-uin(:,:,1).*sin(ang2(:,:,1));
        u_westr(:,:,1)=ur1;
        v_westr(:,:,1)=vr1;
        ur2=uin(:,:,end).*cos(ang2(:,:,end))+vin(:,:,end).*sin(ang2(:,:,end));
        vr2=vin(:,:,end).*cos(ang2(:,:,end))-uin(:,:,end).*sin(ang2(:,:,end));
        u_westr(:,:,end)=ur2;
        v_westr(:,:,end)=vr2;
    end
    clear ang0 ang1 ang2 ur vr vrr ur1 vr1 ur2 vr2 uin vin;

    % --- northern boundary ---
    if obc_north
        u_northr=0*u_north;
        v_northr=0*v_north;
        % - angle -
        ang0=ang(end,:);
        ang1=repmat(ang0,[N,1]);
        nrecord=size(u_north,1); % total number of data record
        for tk=1:nrecord
            ang2(tk,:,:)=ang1;
        end
        % - rotation interior -
        vin=v_north(:,:,2:end-1);
        uin=0.5*(u_north(:,:,1:end-1)+u_north(:,:,2:end));
        ur=uin.*cos(ang2(:,:,2:end-1))+vin.*sin(ang2(:,:,2:end-1));
        vr=vin.*cos(ang2(:,:,2:end-1))-uin.*sin(ang2(:,:,2:end-1));
        urr=0.5*(ur(:,:,1:end-1)+ur(:,:,2:end));
        u_northr(:,:,2:end-1)=urr;
        v_northr(:,:,2:end-1)=vr;
        % - add boundary points -
        ur1=uin(:,:,1).*cos(ang2(:,:,1))+vin(:,:,1).*sin(ang2(:,:,1));
        vr1=vin(:,:,1).*cos(ang2(:,:,1))-uin(:,:,1).*sin(ang2(:,:,1));
        u_northr(:,:,1)=ur1;
        v_northr(:,:,1)=vr1;
        ur2=uin(:,:,end).*cos(ang2(:,:,end))+vin(:,:,end).*sin(ang2(:,:,end));
        vr2=vin(:,:,end).*cos(ang2(:,:,end))-uin(:,:,end).*sin(ang2(:,:,end));
        u_northr(:,:,end)=ur2;
        v_northr(:,:,end)=vr2;
    end
    clear ang0 ang1 ang2 ur vr vrr ur1 vr1 ur2 vr2 uin vin;

    % --- southern boundary ---
    if obc_south
        u_southr=0*u_south;
        v_southr=0*v_south;
        % - angle -
        ang0=ang(1,:);
        ang1=repmat(ang0,[N,1]);
        nrecord=size(u_south,1); % total number of data record
        for tk=1:nrecord
            ang2(tk,:,:)=ang1;
        end
        % - rotation interior -
        vin=v_south(:,:,2:end-1);
        uin=0.5*(u_south(:,:,1:end-1)+u_south(:,:,2:end));
        ur=uin.*cos(ang2(:,:,2:end-1))+vin.*sin(ang2(:,:,2:end-1));
        vr=vin.*cos(ang2(:,:,2:end-1))-uin.*sin(ang2(:,:,2:end-1));
        urr=0.5*(ur(:,:,1:end-1)+ur(:,:,2:end));
        u_southr(:,:,2:end-1)=urr;
        v_southr(:,:,2:end-1)=vr;
        % - add boundary points -
        ur1=uin(:,:,1).*cos(ang2(:,:,1))+vin(:,:,1).*sin(ang2(:,:,1));
        vr1=vin(:,:,1).*cos(ang2(:,:,1))-uin(:,:,1).*sin(ang2(:,:,1));
        u_southr(:,:,1)=ur1;
        v_southr(:,:,1)=vr1;
        ur2=uin(:,:,end).*cos(ang2(:,:,end))+vin(:,:,end).*sin(ang2(:,:,end));
        vr2=vin(:,:,end).*cos(ang2(:,:,end))-uin(:,:,end).*sin(ang2(:,:,end));
        u_southr(:,:,end)=ur2;
        v_southr(:,:,end)=vr2;
    end
    clear ang0 ang1 ang2 ur vr vrr ur1 vr1 ur2 vr2 uin vin;

%
% -------------------------------------------------------------------------
% ------------------------------ Save data --------------------------------
% -------------------------------------------------------------------------
%
    % ------ depth-mean velocities ------
    % ---- eastern boundary ---
    if obc_east
        ua_eastr=[];
        ua=u_eastr;
        zz0=squeeze(zw(:,:,end));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        nrecord=size(u_east,1); % total number of data record
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            ua_eastr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
%
        va_eastr=[];
        ua=v_eastr;
        zz0=squeeze(zw(:,:,end));
        zz0=0.5*(zz0(:,1:end-1)+zz0(:,2:end));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            va_eastr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
    end

    % --- western boundary ---
    if obc_west
        ua_westr=[];
        ua=u_westr;
        zz0=squeeze(zw(:,:,1));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        nrecord=size(u_west,1); % total number of data record
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            ua_westr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
%
        va_westr=[];
        ua=v_westr;
        zz0=squeeze(zw(:,:,1));
        zz0=0.5*(zz0(:,1:end-1)+zz0(:,2:end));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            va_westr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
    end

    % ---- northern boundary ---
    if obc_north
        ua_northr=[];
        ua=u_northr;
        zz0=squeeze(zw(:,end,:));
        zz0=0.5*(zz0(:,1:end-1)+zz0(:,2:end));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        nrecord=size(u_north,1); % total number of data record
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            ua_northr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
%
        va_northr=[];
        ua=v_northr;
        zz0=squeeze(zw(:,end,:));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            va_northr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
    end

    % ---- southern boundary ---
    if obc_south
        ua_southr=[];
        ua=u_southr;
        zz0=squeeze(zw(:,end,:));
        zz0=0.5*(zz0(:,1:end-1)+zz0(:,2:end));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        nrecord=size(u_south,1); % total number of data record
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            ua_southr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
%
        va_southr=[];
        ua=v_southr;
        zz0=squeeze(zw(:,end,:));
        dz=zz0(2:end,:)-zz0(1:end-1,:);
        for tk=1:nrecord
            tem=squeeze(ua(tk,:,:));
            tem=sum(tem.*dz);
            va_southr(tk,:)=tem./(zz0(end,:)-zz0(1,:));
        end
    end
%
    % --- time ---
    t_zeta=tt;
    t_aice=tt;
    t_temp=tt;
    t_salt=tt;
    t_v2d=tt;
    t_v3d=tt;
    % --- rename variables ---
    clear u_east u_west u_north u_south v_east v_west v_north v_south;
%
    if obc_east
       u_east=u_eastr;
       v_east=v_eastr;
       ua_east=ua_eastr;
       va_east=va_eastr;
    end
    
    if obc_west
       u_west=u_westr;
       v_west=v_westr;
       ua_west=ua_westr;
       va_west=va_westr;
    end
    
    if obc_north
       u_north=u_northr;
       v_north=v_northr;
       ua_north=ua_northr;
       va_north=va_northr;
    end
    
    if obc_south
       u_south=u_southr;
       v_south=v_southr;
       ua_south=ua_southr;
       va_south=va_southr;
    end
%
% ---- save data -----
%
    disp('      -> Saving data ...');
   
    outfile0=outfile(fk,:);
    save(outfile0,  'ts','t_zeta','t_aice','t_temp','t_salt','t_v2d','t_v3d'); 
    if obc_east
         save(outfile0,'zeta_east','aice_east','salt_east','temp_east','u_east','v_east','ua_east','va_east','-append');
    end
    if obc_west
         save(outfile0,'zeta_west','aice_west','salt_west','temp_west','u_west','v_west','ua_west','va_west','-append');
    end
    if obc_north
         save(outfile0,'zeta_north','aice_north','salt_north','temp_north','u_north','v_north','ua_north','va_north','-append');
    end
    if obc_south
         save(outfile0,'zeta_south','aice_south','salt_south','temp_south','u_south','v_south','ua_south','va_south','-append');
    end
end
disp('  Done !');

%% ߽糡dye
%dye_01ָʾCDW
%ù(1)ˮ200m   (2)¶ȴ0϶   (3)½򲻷
%˴½ܵĶΪС1000mˮ
clc
clear all;

data_year = 2018;
gridfilename='..\Ross_amundsen_roms_model\initialization_file\data\RAS_grid_32layer.mat';
load(gridfilename);
load('..\Ross_amundsen_roms_model\grid_file\mask_shelf.mat');
Month=['01';'02';'03';'04';'05';'06';'07';'08';'09';'10';'11';'12'];
bry_filename_path='..\Ross_amundsen_roms_model\boundary_file\C_RAS_model_boundary_files\32layer\';
for jmonth=1:12
    bry_filename=[bry_filename_path 'RAS_bry_data_' num2str(data_year) Month(jmonth,:) '.mat'];
    load(bry_filename);
    size_east=size(temp_east);
    size_west=size(temp_west);
    size_north=size(temp_north);
    dye_east_01=zeros(size_east);
    dye_west_01=zeros(size_west);
    dye_north_01=zeros(size_north);
    zr_east=(-squeeze(zr_iceshelf_RAS(end,:,:)))';     %߽
    zr_west=(-squeeze(zr_iceshelf_RAS(1,:,:)))';       %߽
    zr_north=(-squeeze(zr_iceshelf_RAS(:,end,:)))';    %߽
    %east
    for  i=1:size_east(1)
        for j=1:size_east(2)
           for k=1:size_east(3)
               if mask_rho_RAS(end,k)==1&&mask_shelf(end,k)==0
                   if temp_east(i,j,k)>0&&zr_east(j,k)>200
                    dye_east_01(i,j,k)=1;
                   end
               end
           end
        end
    end
    save(bry_filename,'dye_east_01','-append');
    %west
    for  i=1:size_west(1)
        for j=1:size_west(2)
           for k=1:size_west(3)                  
               if mask_rho_RAS(1,k)==1&&mask_shelf(1,k)==0
                   if temp_west(i,j,k)>0&&zr_west(j,k)>200
                        dye_west_01(i,j,k)=1;
                   end
               end
           end
        end
    end
    save(bry_filename,'dye_west_01','-append');
    %north
    for  i=1:size_north(1)
        for j=1:size_north(2)
               for k=1:size_north(3)
                   if mask_rho_RAS(k,end)==1&&mask_shelf(k,end)==0
                       if temp_north(i,j,k)>0&&zr_north(j,k)>200
                            dye_north_01(i,j,k)=1;
                       end
                   end
               end
        end
    end  
    save(bry_filename,'dye_north_01','-append');
    disp(['Complete month: ' num2str(jmonth)])
end

%% дmatļ дncļʹ
clc;
clear all

data_year = 2018;
matfilename = ['..\Ross_amundsen_roms_model\boundary_file\C_RAS_model_boundary_files\32layer\RAS_bry_' num2str(data_year) '.mat'];
Month = ['01';'02';'03';'04';'05';'06';'07';'08';'09';'10';'11';'12'];
days = ['01';'02';'03';'04';'05';'06';'07';'08';'09';'10';'11';'12';'13';'14';'15';
    '16';'17';'18';'19';'20';'21';'22';'23';'24';'25';'26';'27';'28';'29';'30';'31'];
Monthabb = ['Jan';'Feb';'Mar';'Apr';'May';'Jun';'Jul';'Aug';'Sep';'Oct';'Nov';'Dec'];

for jmonth=1:12
   %жǷ
   if data_year==2000||data_year==2004||data_year==2008||data_year==2012||data_year==2016
        Monthdays=[31;29;31;30;31;30;31;31;30;31;30;31];   %
   else
        Monthdays=[31;28;31;30;31;30;31;31;30;31;30;31];   %
   end
   bryfilename=['..\Ross_amundsen_roms_model\boundary_file\C_RAS_model_boundary_files\32layer\RAS_bry_data_',num2str(data_year),Month(jmonth,:),'.mat'];
   load(bryfilename);
   aice_west_tmp=permute(aice_west,[2,1]);
   aice_east_tmp=permute(aice_east,[2,1]);
   aice_north_tmp=permute(aice_north,[2,1]);
   zeta_west_tmp=permute(zeta_west,[2,1]);
   zeta_east_tmp=permute(zeta_east,[2,1]);
   zeta_north_tmp=permute(zeta_north,[2,1]);
   salt_west_tmp=permute(salt_west,[3,2,1]);
   salt_east_tmp=permute(salt_east,[3,2,1]);
   salt_north_tmp=permute(salt_north,[3,2,1]);
   temp_west_tmp=permute(temp_west,[3,2,1]);
   temp_east_tmp=permute(temp_east,[3,2,1]);
   temp_north_tmp=permute(temp_north,[3,2,1]);
   ua_west_tmp=permute(ua_west,[3,2,1]);
   ua_east_tmp=permute(ua_east,[3,2,1]);
   ua_north_tmp=permute(ua_north,[3,2,1]);
   va_west_tmp=permute(va_west,[3,2,1]);
   va_east_tmp=permute(va_east,[3,2,1]);
   va_north_tmp=permute(va_north,[3,2,1]);
   dye_west_01tmp=permute(dye_west_01,[3,2,1]);
   dye_east_01tmp=permute(dye_east_01,[3,2,1]);
   dye_north_01tmp=permute(dye_north_01,[3,2,1]);
   %
   if jmonth==1
      daystart=1;
      dayend=Monthdays(jmonth);
   else
      daystart=numdim+1;
      dayend=daystart+Monthdays(jmonth)-1;
   end
   aice_west_bry(:,daystart:dayend)=aice_west_tmp;
   aice_east_bry(:,daystart:dayend)=aice_east_tmp;
   aice_north_bry(:,daystart:dayend)=aice_north_tmp;
   zeta_west_bry(:,daystart:dayend)=zeta_west_tmp;
   zeta_east_bry(:,daystart:dayend)=zeta_east_tmp;
   zeta_north_bry(:,daystart:dayend)=zeta_north_tmp;
   salt_west_bry(:,:,daystart:dayend)=salt_west_tmp;
   salt_east_bry(:,:,daystart:dayend)=salt_east_tmp;
   salt_north_bry(:,:,daystart:dayend)=salt_north_tmp;
   temp_west_bry(:,:,daystart:dayend)=temp_west_tmp;
   temp_east_bry(:,:,daystart:dayend)=temp_east_tmp;
   temp_north_bry(:,:,daystart:dayend)=temp_north_tmp;
   ubar_west_bry(:,daystart:dayend)=ua_west_tmp;
   ubar_east_bry(:,daystart:dayend)=ua_east_tmp;
   ubar_north_bry(:,daystart:dayend)=ua_north_tmp;
   vbar_west_bry(:,daystart:dayend)=va_west_tmp;
   vbar_east_bry(:,daystart:dayend)=va_east_tmp;
   vbar_north_bry(:,daystart:dayend)=va_north_tmp;
   dye_west_01_bry(:,:,daystart:dayend)=dye_west_01tmp;
   dye_east_01_bry(:,:,daystart:dayend)=dye_east_01tmp;
   dye_north_01_bry(:,:,daystart:dayend)=dye_north_01tmp;
   bry_time(daystart:dayend,1)=t_aice(:,1);
   [numdim,~]=size(bry_time);
   disp([Monthabb(jmonth,:) '(days): ' num2str(daystart) ' to ' num2str(dayend) ' completed!'])
end
%Ϊ0
salt_south_bry=zeros(size(salt_north_bry));
temp_south_bry=zeros(size(temp_north_bry));
zeta_south_bry=zeros(size(zeta_north_bry));
ubar_south_bry=zeros(size(ubar_north_bry));
vbar_south_bry=zeros(size(vbar_north_bry));
aice_south_bry=zeros(size(aice_north_bry));
dye_south_01_bry=zeros(size(dye_north_01_bry));
dye_west_02_bry=zeros(size(dye_west_01_bry));
dye_east_02_bry=zeros(size(dye_east_01_bry));
dye_north_02_bry=zeros(size(dye_north_01_bry));
dye_south_02_bry=zeros(size(dye_south_01_bry));
dye_west_03_bry=zeros(size(dye_west_01_bry));
dye_east_03_bry=zeros(size(dye_east_01_bry));
dye_north_03_bry=zeros(size(dye_north_01_bry));
dye_south_03_bry=zeros(size(dye_south_01_bry));
save(matfilename,'aice_west_bry','aice_east_bry','aice_north_bry',...
    'zeta_west_bry','zeta_east_bry','zeta_north_bry',...
    'salt_west_bry','salt_east_bry','salt_north_bry',...
    'temp_west_bry','temp_east_bry','temp_north_bry',...
    'ubar_west_bry','ubar_east_bry','ubar_north_bry',...
    'vbar_west_bry','vbar_east_bry','vbar_north_bry',...
    'dye_west_01_bry','dye_east_01_bry','dye_north_01_bry','bry_time');
save(matfilename,'salt_south_bry','temp_south_bry','zeta_south_bry',...
    'ubar_south_bry','vbar_south_bry','aice_south_bry','-append');
save(matfilename,'dye_south_01_bry','dye_west_02_bry','dye_east_02_bry',...
    'dye_north_02_bry','dye_south_02_bry','dye_west_03_bry','dye_east_03_bry',...
    'dye_north_03_bry','dye_south_03_bry','-append');

%% ӳϫ,ԴTPXO9
%TPXOϵкģոѧ(Oregon State University)
% Gary EgbertLanna Erofeevaȫ򺣳ģ
clc;
clear all;

tidefilename=['..\Ross_amundsen_roms_model\boundary_file\C_RAS_model_boundary_files\tide\RAS_tide.mat'];
load(tidefilename);
tide_time_index=tide_time-tide_time(1,:); 
mybasedate = datenum(2003,1,1);       
for data_year = 2003:2019
    matfilename = ['..\Ross_amundsen_roms_model\boundary_file\C_RAS_model_boundary_files\tide\RAS_bry_' num2str(data_year) '.mat'];  
    yeartime_begin = datenum(data_year,1,1)-mybasedate;
    yeartime_end = datenum(data_year+1,1,1)-mybasedate;
    yearbegin_mark = find(tide_time_index==yeartime_begin);
    yearend_mark = find(tide_time_index==yeartime_end)-1;
    ubar_east_bry = ubar_east(:,yearbegin_mark:yearend_mark);
    ubar_west_bry = ubar_west(:,yearbegin_mark:yearend_mark);
    ubar_north_bry = ubar_north(:,yearbegin_mark:yearend_mark);
    ubar_south_bry = zeros(size(ubar_north_bry));
    vbar_east_bry = vbar_east(:,yearbegin_mark:yearend_mark);
    vbar_west_bry = vbar_west(:,yearbegin_mark:yearend_mark);
    vbar_north_bry = vbar_north(:,yearbegin_mark:yearend_mark);
    vbar_south_bry = zeros(size(vbar_north_bry));
    zeta_east_bry = zeta_east(:,yearbegin_mark:yearend_mark);
    zeta_west_bry = zeta_west(:,yearbegin_mark:yearend_mark);
    zeta_north_bry = zeta_north(:,yearbegin_mark:yearend_mark);
    zeta_south_bry = zeros(size(zeta_north_bry));
    tide_time = tide_time_index(yearbegin_mark:yearend_mark,:);
    save(matfilename,'ubar_east_bry','ubar_west_bry','ubar_north_bry','ubar_south_bry','-append');
    save(matfilename,'vbar_east_bry','vbar_west_bry','vbar_north_bry','vbar_south_bry','-append');
    save(matfilename,'zeta_east_bry','zeta_west_bry','zeta_north_bry','zeta_south_bry','-append');
    save(matfilename,'tide_time','-append');
    disp(['==> ' num2str(data_year) ' : add tide into boundary field successfully!']);
end







