% Generate grid file for ROMS model
% Written by Xie Chuan,
% Date : 10-11-2021
% 
clc;
clear all; 
close all;
% -------------------------------------------------------------------------
% ------------------------- user settings ---------------------------------
% -------------------------------------------------------------------------
%
title='RAS';
%
% Common parameters
%
ROMS_grdfiles_dir=['..\Ross_amundsen_roms_model\grid_file\'];
grdfilename=[ROMS_grdfiles_dir title '_grd_32layer_old.nc'];
% 
%
[Mp,Lp]=size(h);
L=Lp-1;
M=Mp-1;
Np=N+1;
% --- grid dimensions ---    
Lm=Lp-2;      % Number of I-direction INTERIOR RHO-points
Mm=Mp-2;      % Number of J-direction INTERIOR RHO-points
save('RAS_grid_var_32layer.mat','theta_s','theta_b','Tcline','hc','s_w','s_rho'...
      ,'Cs_r','Cs_w','h','hraw','zice','f','pm','pn','dmde','dndx','xl','el'...
      ,'x_rho','y_rho','x_u','y_u','x_v','y_v','x_psi','y_psi','x_vert','y_vert'...
      ,'lon_rho','lat_rho','lon_u','lat_u'...
      ,'lon_v','lat_v','lon_psi','lat_psi','lon_vert','lat_vert','spherical','angle'...
     ,'N','L','M','Np','Lp','Mp','mask_rho','mask_u','mask_v','mask_psi');

save('RAS_grid_var_32layer.mat','mask_rho','mask_u','mask_v','mask_psi','-append');

%%  format: NETCDF4_CLASSIC
% -------------------------------------------------------------------------
% ------------------------- Create netcdf file ----------------------------
% -------------------------------------------------------------------------
%
% clc;
% clear all; 
% close all;
% Common parameters
%
ROMS_grdfiles_dir='..\RAS_roms_model_xiechuan\grid_file\';
grdfilename=[ROMS_grdfiles_dir,'RAS_grd_32layer_new02.nc'];
% 
%
Mp=1000;
Lp=1000;
N=32;
L=Lp-1;
M=Mp-1;
Np=N+1;
% --- grid dimensions ---    
Lm=Lp-2;      % Number of I-direction INTERIOR RHO-points
Mm=Mp-2;      % Number of J-direction INTERIOR RHO-points
% ------------ creat file -----------
disp('  Creating NC file...')
% --------- define dimensions ---------
disp('      => Defining Dimensions...')
dim_xi_rho = Lp;
dim_xi_u = L;
dim_xi_v = Lp;
dim_xi_psi = L;
dim_xi_vert = Lp+1;
dim_eta_rho = Mp;
dim_eta_u = Mp;
dim_eta_v = M; 
dim_eta_psi = M; 
dim_eta_vert = Mp+1; 
dim_bath = 1;
dim_s_rho = N;
dim_s_w = Np;
dim_one = 1;
% 
% --------- define Variables and attributes ---------
disp('      => Defining Variables and Attributes...')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'theta_s','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(grdfilename,'theta_s','long_name','S-coordinate surface control parameter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'theta_b','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(grdfilename,'theta_b','long_name','S-coordinate bottom control parameter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'Tcline','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(grdfilename,'Tcline','long_name','S-coordinate surface/bottom layer width')
ncwriteatt(grdfilename,'Tcline','units','meter')
% % %--------------------------------------------------------------------------
nccreate(grdfilename,'hc','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(grdfilename,'hc','long_name','S-coordinate parameter, critical depth')
ncwriteatt(grdfilename,'hc','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'s_rho','Dimensions',{'s_rho',dim_s_rho},'FillValue','disable');
ncwriteatt(grdfilename,'s_rho','long_name','S-coordinate at RHO-points')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'s_w','Dimensions',{'s_w',dim_s_w},'FillValue','disable');
ncwriteatt(grdfilename,'s_w','long_name','S-coordinate at W-points')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'Cs_r','Dimensions',{'s_rho',dim_s_rho},'FillValue','disable');
ncwriteatt(grdfilename,'Cs_r','long_name','S-coordinate stretching function at RHO-points')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'Cs_w','Dimensions',{'s_w',dim_s_w},'FillValue','disable');
ncwriteatt(grdfilename,'Cs_w','long_name','S-coordinate stretching function at W-points')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'h','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'h','long_name','bathymetry at RHO-points')
ncwriteatt(grdfilename,'h','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'zice','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'zice','long_name','iceshelf depth at RHO-points')
ncwriteatt(grdfilename,'zice','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'zice_raw','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'zice_raw','long_name','raw iceshelf depth at RHO-points')
ncwriteatt(grdfilename,'zice_raw','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'hraw','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho,'bath',dim_bath},'FillValue','disable');
ncwriteatt(grdfilename,'hraw','long_name','raw bathymetry at RHO-points')
ncwriteatt(grdfilename,'hraw','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'f','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'f','long_name','Coriolis parameter at RHO-points')
ncwriteatt(grdfilename,'f','units','second-1')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'pm','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'pm','long_name','curvilinear coordinate metric in XI')
ncwriteatt(grdfilename,'pm','units','meter-1')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'pn','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'pn','long_name','curvilinear coordinate metric in ETA')
ncwriteatt(grdfilename,'pn','units','meter-1')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'dmde','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'dmde','long_name','XI derivative of inverse metric factor pn')
ncwriteatt(grdfilename,'dmde','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'dndx','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'dndx','long_name','ETA derivative of inverse metric factor pm')
ncwriteatt(grdfilename,'dndx','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'xl','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(grdfilename,'xl','long_name','domain length in the XI-direction')
ncwriteatt(grdfilename,'xl','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'el','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(grdfilename,'el','long_name','domain length in the ETA-direction')
ncwriteatt(grdfilename,'el','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'x_rho','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'x_rho','long_name','x location of RHO-points')
ncwriteatt(grdfilename,'x_rho','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'y_rho','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'y_rho','long_name','y location of RHO-points')
ncwriteatt(grdfilename,'y_rho','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'x_u','Dimensions',{'xi_u',dim_xi_u,'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(grdfilename,'x_u','long_name','x location of U-points')
ncwriteatt(grdfilename,'x_u','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'y_u','Dimensions',{'xi_u',dim_xi_u,'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(grdfilename,'y_u','long_name','y location of U-points')
ncwriteatt(grdfilename,'y_u','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'x_v','Dimensions',{'xi_v',dim_xi_v,'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(grdfilename,'x_v','long_name','x location of V-points')
ncwriteatt(grdfilename,'x_v','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'y_v','Dimensions',{'xi_v',dim_xi_v,'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(grdfilename,'y_v','long_name','y location of V-points')
ncwriteatt(grdfilename,'y_v','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'x_psi','Dimensions',{'xi_psi',dim_xi_psi,'eta_psi',dim_eta_psi},'FillValue','disable');
ncwriteatt(grdfilename,'x_psi','long_name','x location of PSI-points')
ncwriteatt(grdfilename,'x_psi','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'y_psi','Dimensions',{'xi_psi',dim_xi_psi,'eta_psi',dim_eta_psi},'FillValue','disable');
ncwriteatt(grdfilename,'y_psi','long_name','y location of PSI-points')
ncwriteatt(grdfilename,'y_psi','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'x_vert','Dimensions',{'xi_vert',dim_xi_vert,'eta_vert',dim_eta_vert},'FillValue','disable');
ncwriteatt(grdfilename,'x_vert','long_name','x location of cell verticies')
ncwriteatt(grdfilename,'x_vert','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'y_vert','Dimensions',{'xi_vert',dim_xi_vert,'eta_vert',dim_eta_vert},'FillValue','disable');
ncwriteatt(grdfilename,'y_vert','long_name','y location of cell verticies')
ncwriteatt(grdfilename,'y_vert','units','meter')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lon_rho','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'lon_rho','long_name','longitude of RHO-points')
ncwriteatt(grdfilename,'lon_rho','units','degree_east')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lat_rho','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'lat_rho','long_name','latitute of RHO-points')
ncwriteatt(grdfilename,'lat_rho','units','degree_north')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lon_u','Dimensions',{'xi_u',dim_xi_u,'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(grdfilename,'lon_u','long_name','longitude of U-points')
ncwriteatt(grdfilename,'lon_u','units','degree_east')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lat_u','Dimensions',{'xi_u',dim_xi_u,'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(grdfilename,'lat_u','long_name','latitute of U-points')
ncwriteatt(grdfilename,'lat_u','units','degree_north')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lon_v','Dimensions',{'xi_v',dim_xi_v,'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(grdfilename,'lon_v','long_name','longitude of V-points')
ncwriteatt(grdfilename,'lon_v','units','degree_east')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lat_v','Dimensions',{'xi_v',dim_xi_v,'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(grdfilename,'lat_v','long_name','latitute of V-points')
ncwriteatt(grdfilename,'lat_v','units','degree_north')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lon_psi','Dimensions',{'xi_psi',dim_xi_psi,'eta_psi',dim_eta_psi},'FillValue','disable');
ncwriteatt(grdfilename,'lon_psi','long_name','longitude of PSI-points')
ncwriteatt(grdfilename,'lon_psi','units','degree_east')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lat_psi','Dimensions',{'xi_psi',dim_xi_psi,'eta_psi',dim_eta_psi},'FillValue','disable');
ncwriteatt(grdfilename,'lat_psi','long_name','latitude of PSI-points')
ncwriteatt(grdfilename,'lat_psi','units','degree_north')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lon_vert','Dimensions',{'xi_vert',dim_xi_vert,'eta_vert',dim_eta_vert},'FillValue','disable');
ncwriteatt(grdfilename,'lon_vert','long_name','longitude of cell verticies')
ncwriteatt(grdfilename,'lon_vert','units','degree_east')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'lat_vert','Dimensions',{'xi_vert',dim_xi_vert,'eta_vert',dim_eta_vert},'FillValue','disable');
ncwriteatt(grdfilename,'lat_vert','long_name','latitude of cell verticies')
ncwriteatt(grdfilename,'lat_vert','units','degree_north')
% %--------------------------------------------------------------------------
nccreate(grdfilename,'spherical','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(grdfilename,'spherical','long_name','grid type logical switch')
%--------------------------------------------------------------------------
nccreate(grdfilename,'angle','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'angle','long_name','angle between XI-axis and EAST')
ncwriteatt(grdfilename,'angle','units','radians')
%--------------------------------------------------------------------------
nccreate(grdfilename,'mask_rho','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'mask_rho','long_name','mask on RHO-points')
%--------------------------------------------------------------------------
nccreate(grdfilename,'mask_u','Dimensions',{'xi_u',dim_xi_u,'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(grdfilename,'mask_u','long_name','mask on U-points')
%--------------------------------------------------------------------------
nccreate(grdfilename,'mask_v','Dimensions',{'xi_v',dim_xi_v,'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(grdfilename,'mask_v','long_name','mask on V-points')
%--------------------------------------------------------------------------
nccreate(grdfilename,'mask_psi','Dimensions',{'xi_psi',dim_xi_psi,'eta_psi',dim_eta_psi},'FillValue','disable');
ncwriteatt(grdfilename,'mask_psi','long_name','mask on psi-points')
%--------------------------------------------------------------------------
nccreate(grdfilename,'mask_nudge','Dimensions',{'xi_rho',dim_xi_rho,'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(grdfilename,'mask_nudge','long_name','mask used for nudging')
%--------------------------------------------------------------------------
disp('      => Loading Grid data ...');
grd_oldfilename='H:\RAS_roms_model_xiechuan\grid_file\RAS_grd_32layer_new.nc';
% %-----Read the grid file-------
N = 32 ;
theta_s = ncread(grd_oldfilename,'theta_s');
theta_b = ncread(grd_oldfilename,'theta_b');
Tcline = 200;
hc = 200;
s_w = ncread(grd_oldfilename,'s_w');
s_rho = ncread(grd_oldfilename,'s_rho');
Cs_r = ncread(grd_oldfilename,'Cs_r');
Cs_w = ncread(grd_oldfilename,'Cs_w');
h = ncread(grd_oldfilename,'h');
hraw = ncread(grd_oldfilename,'hraw');
zice = ncread(grd_oldfilename,'zice');
f = ncread(grd_oldfilename,'f');
pm = ncread(grd_oldfilename,'pm');
pn = ncread(grd_oldfilename,'pn');
dmde = ncread(grd_oldfilename,'dmde');
dndx = ncread(grd_oldfilename,'dndx');
xl = ncread(grd_oldfilename,'xl');
el = ncread(grd_oldfilename,'el');
x_rho = ncread(grd_oldfilename,'x_rho');
y_rho = ncread(grd_oldfilename,'y_rho');
x_u = ncread(grd_oldfilename,'x_u');
y_u = ncread(grd_oldfilename,'y_u');
x_v = ncread(grd_oldfilename,'x_v');
y_v  = ncread(grd_oldfilename,'y_v');
x_psi = ncread(grd_oldfilename,'x_psi');
y_psi  = ncread(grd_oldfilename,'y_psi');
x_vert  = ncread(grd_oldfilename,'x_vert');
y_vert  = ncread(grd_oldfilename,'y_vert');
lon_rho = ncread(grd_oldfilename,'lon_rho');
lat_rho = ncread(grd_oldfilename,'lat_rho');
lon_u = ncread(grd_oldfilename,'lon_u');
lat_u = ncread(grd_oldfilename,'lat_u');
lon_v = ncread(grd_oldfilename,'lon_v');
lat_v = ncread(grd_oldfilename,'lat_v');
lon_psi = ncread(grd_oldfilename,'lon_psi');
lat_psi = ncread(grd_oldfilename,'lat_psi');
lon_vert = ncread(grd_oldfilename,'lon_vert');
lat_vert = ncread(grd_oldfilename,'lat_vert');
spherical = ncread(grd_oldfilename,'spherical');
angle = ncread(grd_oldfilename,'angle');
mask_rho = ncread(grd_oldfilename,'mask_rho');
mask_u = ncread(grd_oldfilename,'mask_u');
mask_v = ncread(grd_oldfilename,'mask_v');
mask_psi = ncread(grd_oldfilename,'mask_psi');

% ---------------- write variables -----------------
disp('      => Filling Variables...')
ncwrite(grdfilename,'theta_s',theta_s);
ncwrite(grdfilename,'theta_b',theta_b);
ncwrite(grdfilename,'Tcline',Tcline);
ncwrite(grdfilename,'hc',hc);
ncwrite(grdfilename,'s_rho',s_rho);
ncwrite(grdfilename,'s_w',s_w);
ncwrite(grdfilename,'Cs_r',Cs_r);
ncwrite(grdfilename,'Cs_w',Cs_w);
ncwrite(grdfilename,'h',h);
ncwrite(grdfilename,'zice',zice);
ncwrite(grdfilename,'zice_raw',zice);
ncwrite(grdfilename,'hraw',hraw);
ncwrite(grdfilename,'f',f);
ncwrite(grdfilename,'pm',pm);
ncwrite(grdfilename,'pn',pn);
ncwrite(grdfilename,'dmde',dmde);
ncwrite(grdfilename,'dndx',dndx);
ncwrite(grdfilename,'xl',xl);
ncwrite(grdfilename,'el',el);
ncwrite(grdfilename,'x_rho',x_rho);
ncwrite(grdfilename,'y_rho',y_rho);
ncwrite(grdfilename,'x_u',x_u);
ncwrite(grdfilename,'y_u',y_u);
ncwrite(grdfilename,'x_v',x_v);
ncwrite(grdfilename,'y_v',y_v);
ncwrite(grdfilename,'x_psi',x_psi);
ncwrite(grdfilename,'y_psi',y_psi);
ncwrite(grdfilename,'x_vert',x_vert);
ncwrite(grdfilename,'y_vert',y_vert);
ncwrite(grdfilename,'lon_rho',lon_rho);
ncwrite(grdfilename,'lat_rho',lat_rho);
ncwrite(grdfilename,'lon_u',lon_u);
ncwrite(grdfilename,'lat_u',lat_u);
ncwrite(grdfilename,'lon_v',lon_v);
ncwrite(grdfilename,'lat_v',lat_v);
ncwrite(grdfilename,'lon_psi',lon_psi);
ncwrite(grdfilename,'lat_psi',lat_psi);
ncwrite(grdfilename,'lon_vert',lon_vert);
ncwrite(grdfilename,'lat_vert',lat_vert);
ncwrite(grdfilename,'spherical',spherical);
ncwrite(grdfilename,'angle',angle);
ncwrite(grdfilename,'mask_rho',mask_rho);
ncwrite(grdfilename,'mask_u',mask_u);
ncwrite(grdfilename,'mask_v',mask_v);
ncwrite(grdfilename,'mask_psi',mask_psi);
ncwrite(grdfilename,'mask_nudge',mask_nudge);

%------------------- Write Global Attributes -----------------
disp('      => Creating Global Attributes...')
ncwriteatt(grdfilename,'/','History','GRID file for RAS model');
ncwriteatt(grdfilename,'/','Create_time',datestr(now));
disp('  Done !');

