%code for Figure.11 in GMD
%Chuan Xie (xiechuan@sjtu.edu.cn)
clc;
clear all;

%% load model info
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
load('..\grid_file\RAS_depth.mat');
load('..\grid_file\mask_shelf.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
zice=ncread(grdfilename,'zice');
h=ncread(grdfilename,'h');
for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end
end

%Calculates sea pressure from depth 
for k=1:32
   pr(:,:,k) = gsw_p_from_z(zr(:,:,k),lat_rho);
end

%% ca108
%only 475m and 30m
load("..\Processed_CurrentMeter_Data_Adare_Basin\NBP1101_current_meter_ca108_hourly.mat")
lat_mooring=ca108.meta.lat;
lon_mooring=ca108.meta.lon;

salt_layer01=ca108.sa30;
temperature_layer01=ca108.te30;
press_layer01=ca108.pr30;
pressure_layer01=mean(ca108.pr30,'omitnan');

salt_ca108=mean(reshape(salt_layer01(1,1:120*219),120,219),1,'omitnan');
temp_ca108=mean(reshape(temperature_layer01(1,1:120*219),120,219),1,'omitnan');
press_ca108=mean(reshape(press_layer01(1,1:120*219),120,219),1,'omitnan');
gamma_ca108_mooring=gamma_GP_from_SP_pt(salt_ca108',temp_ca108',press_ca108',lon_mooring,lat_mooring);

% find point in the model grid
lat_mooring=ca108.meta.lat;
lon_mooring=ca108.meta.lon; 
depth=ca108.meta.depth;   
diff_lon=lon_rho-lon_mooring;
diff_lat=lat_rho-lat_mooring;
for ii=1:1000
   for jj=1:1000
        if abs(diff_lon(ii,jj))>1||abs(diff_lat(ii,jj))>1
             dis(ii,jj)=NaN;
        else
             dis(ii,jj)=distance(lat_rho(ii,jj),lon_rho(ii,jj),lat_mooring,lon_mooring);
        end
   end
end
[M,I]=find(dis==min(min(dis)));
Depth_profile=squeeze(zr(M,I,:));
[M_DEPTH,I_DEPTH]=min(abs(Depth_profile-(-pressure_layer01)));


RAS_data_dirname=['..\Base_simulation_nudging\'];
index=1;
start = [M I I_DEPTH 1];   % Start location along each coordinate
count_rho = [1 1 1 Inf];

for filenum=74:96
    filename=[RAS_data_dirname,'RAS_avg_0',num2str(filenum,'%03d'),'.nc'];
    salt_tmp=ncread(filename,'salt',start,count_rho);
    temp_tmp=ncread(filename,'temp',start,count_rho);
    salt_ca108_RAISE(index:index+9)=squeeze(salt_tmp);
    temp_ca108_RAISE(index:index+9)=squeeze(temp_tmp);
    [~,index]=size(salt_ca108_RAISE);
    index=index+1;
    disp(filenum);
    clear salt_tmp temp_tmp
end
press_model=ones(1,219)*pr(M,I,I_DEPTH);
gamma_ca108_RAISE=gamma_GP_from_SP_pt(salt_ca108_RAISE(1,4:end-8)',temp_ca108_RAISE(1,4:end-8)',press_model',lon_rho(M,I),lat_rho(M,I));

save('..\GMD_2024\data\Figure-11\c108-1735m-gamma.mat','gamma_ca108_mooring','gamma_ca108_RAISE');


RAS_data_dirname=['..\Base_simulation_nudging_Melt\'];
index=1;
start = [M I I_DEPTH 1];   % Start location along each coordinate
count_rho = [1 1 1 Inf];
for filenum=74:96
    filename=[RAS_data_dirname,'RAS_avg_0',num2str(filenum,'%03d'),'.nc'];
    salt_tmp=ncread(filename,'salt',start,count_rho);
    temp_tmp=ncread(filename,'temp',start,count_rho);
    salt_ca108_RAISE_Melt(index:index+9)=squeeze(salt_tmp);
    temp_ca108_RAISE_Melt(index:index+9)=squeeze(temp_tmp);
    [~,index]=size(salt_ca108_RAISE_Melt);
    index=index+1;
    disp(filenum);
    clear salt_tmp temp_tmp
end
press_model=ones(1,219)*pr(M,I,I_DEPTH);
gamma_ca108_RAISE_Melt=gamma_GP_from_SP_pt(salt_ca108_RAISE_Melt(1,4:end-8)',temp_ca108_RAISE_Melt(1,4:end-8)',press_model',lon_rho(M,I),lat_rho(M,I));

save('..\GMD_2024\data\Figure-11\c108-1735m-gamma.mat','gamma_ca108_RAISE_Melt','-append');


%% ca208
load("..\Processed_CurrentMeter_Data_Adare_Basin\NBP1101_current_meter_ca208_hourly.mat")
lat_mooring=ca208.meta.lat;
lon_mooring=ca208.meta.lon; 

salt_layer01=ca208.sa30;
temperature_layer01=ca208.te30;
press_layer01=ca208.pr30;
pressure_layer01=mean(ca208.pr30,'omitnan');

salt_ca208=mean(reshape(salt_layer01(1,1:120*219),120,219),1,'omitnan');
temp_ca208=mean(reshape(temperature_layer01(1,1:120*219),120,219),1,'omitnan');
press_ca208=mean(reshape(press_layer01(1,1:120*219),120,219),1,'omitnan');
gamma_ca208_mooring=gamma_GP_from_SP_pt(salt_ca208',temp_ca208',press_ca208',lon_mooring,lat_mooring);

% find point in the model grid
lat_mooring=ca208.meta.lat;
lon_mooring=ca208.meta.lon; 
depth=ca208.meta.depth;   
diff_lon=lon_rho-lon_mooring;
diff_lat=lat_rho-lat_mooring;
for ii=1:1000
   for jj=1:1000
        if abs(diff_lon(ii,jj))>1||abs(diff_lat(ii,jj))>1
             dis(ii,jj)=NaN;
        else
             dis(ii,jj)=distance(lat_rho(ii,jj),lon_rho(ii,jj),lat_mooring,lon_mooring);
        end
   end
end
[M,I]=find(dis==min(min(dis)));
Depth_profile=squeeze(zr(M,I,:));
[M_DEPTH,I_DEPTH]=min(abs(Depth_profile-(-pressure_layer01)));

RAS_data_dirname=['..\Base_simulation_nudging\'];
index=1;
start = [M I I_DEPTH 1];   % Start location along each coordinate
count_rho = [1 1 1 Inf];
for filenum=74:96
    filename=[RAS_data_dirname,'RAS_avg_0',num2str(filenum,'%03d'),'.nc'];
    salt_tmp=ncread(filename,'salt',start,count_rho);
    temp_tmp=ncread(filename,'temp',start,count_rho);
    salt_ca208_RAISE(index:index+9)=squeeze(salt_tmp);
    temp_ca208_RAISE(index:index+9)=squeeze(temp_tmp);
    [~,index]=size(salt_ca208_RAISE);
    index=index+1;
    disp(filenum);
    clear salt_tmp temp_tmp
end
press_model=ones(1,219)*pr(M,I,I_DEPTH);
gamma_ca208_RAISE = gamma_GP_from_SP_pt(salt_ca208_RAISE(1,4:end-8)',temp_ca208_RAISE(1,4:end-8)',press_model',lon_rho(M,I),lat_rho(M,I));

save('..\GMD_2024\data\Figure-11\c208-1929m-gamma.mat','gamma_ca208_mooring','gamma_ca208_RAISE');


RAS_data_dirname=['..\Base_simulation_nudging_MeltH\'];
index=1;
start = [M I I_DEPTH 1];   % Start location along each coordinate
count_rho = [1 1 1 Inf];
for filenum=74:96
    filename=[RAS_data_dirname,'RAS_avg_0',num2str(filenum,'%03d'),'.nc'];
    salt_tmp=ncread(filename,'salt',start,count_rho);
    temp_tmp=ncread(filename,'temp',start,count_rho);
    salt_ca208_RAISE_melt(index:index+9)=squeeze(salt_tmp);
    temp_ca208_RAISE_melt(index:index+9)=squeeze(temp_tmp);
    [~,index]=size(salt_ca208_RAISE_melt);
    index=index+1;
    disp(filenum);
    clear salt_tmp temp_tmp
end
press_model=ones(1,219)*pr(M,I,I_DEPTH);
gamma_ca208_RAISE_Melt = gamma_GP_from_SP_pt(salt_ca208_RAISE_melt(1,4:end-8)',temp_ca208_RAISE_melt(1,4:end-8)',press_model',lon_rho(M,I),lat_rho(M,I));

save('..\GMD_2024\data\Figure-11\c208-1929m-gamma.mat','gamma_ca208_RAISE_Melt','-append');


%% ------------------------Neutral Density-------------------------
dir_name='..\GMD_2024\data\Figure-11\';

load([dir_name,'\c108-1735m-gamma.mat']);
density_RAISE=smooth(gamma_ca108_RAISE,6);
density_mooring=smooth(gamma_ca108_mooring,6);
[R,P]=corrcoef(density_RAISE,density_mooring);
[~,total_index]=size(density_mooring');
density_RAISE_melt=smooth(gamma_ca108_RAISE_Melt,6);

%root-mean-square errors
E1_ca108=rmse(gamma_ca108_RAISE,gamma_ca108_mooring);
E2_ca108=rmse(gamma_ca108_RAISE_Melt,gamma_ca108_mooring);

set(gcf,'unit','centimeters','position',[1 5 21.78 9.6]);
ha=tight_subplot(1,2,[.02 .1],[.15 .1],[.1 .03]);

load([dir_name,'NBP1101_current_meter_ca108_hourly.mat'])
lat_mooring_CA1=ca108.meta.lat;
lon_mooring_CA1=ca108.meta.lon; 
load([dir_name,'NBP1101_current_meter_ca208_hourly.mat'])
lat_mooring_CA2=ca208.meta.lat;
lon_mooring_CA2=ca208.meta.lon;

%------------------------Neutral Density-------------------------
axes(ha(1));
plot(density_mooring,'color','#000000','linewidth',1.9);
hold on
plot(density_RAISE,'color','#C4B112','linewidth',1.9);
plot(density_RAISE_melt,'color','#4682B4','LineStyle','-','linewidth',1.6);
legend({'Mooring data','CTRL','Melt+'},'Location','northwest','FontSize',10);
xlim([0,total_index]);
ylim([28.2,28.5]);
ylabel('Neutral Density [kg m^{-3}]','fontsize',10);
xticks([1:72:total_index total_index]);
xticklabels({'01/2008','01/2009','01/2010','01/2011'});
% xlabel('Date','fontsize',9);
box on
grid on
text(107,28.23,['\bf R=',num2str(R(1,2),'%.2f'),', P<0.001'],'color','k','fontsize',12);
text(164,28.47,'\bf 1735 m','fontsize',12);
title('\bf (a)','fontsize',10);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'FontName','SansSarif');
set(gca,'Fontsize',11); 
set(gca,'linewidth',1.5);


load([dir_name,'c208-1929m-gamma.mat']);
density_RAISE=smooth(gamma_ca208_RAISE,6);
density_mooring=smooth(gamma_ca208_mooring,6);
[R,P]=corrcoef(density_RAISE,density_mooring);
[~,total_index]=size(density_mooring');
density_RAISE_melt=smooth(gamma_ca208_RAISE_Melt,6);

%root-mean-square errors
E1_ca208=rmse(gamma_ca208_RAISE,gamma_ca208_mooring);
E2_ca208=rmse(gamma_ca208_RAISE_Melt,gamma_ca208_mooring);
E1_total=(E1_ca108+E1_ca208)./2;
E2_total=(E2_ca108+E2_ca208)./2;

axes(ha(2));
plot(density_mooring,'color','#000000','linewidth',1.9);
hold on
plot(density_RAISE,'color','#C4B112','linewidth',1.9);
plot(density_RAISE_melt,'color','#4682B4','LineStyle','-','linewidth',1.6);
legend({'Mooring data','CTRL','Melt+'},'Location','northwest','FontSize',10);
xlim([0,total_index]);
ylim([28.2,28.5]);
% ylabel('Neutral Density (kg m^{-3})','fontsize',10);
xticks([1:72:total_index total_index]);
xticklabels({'01/2008','01/2009','01/2010','01/2011'});
% xlabel('Date','fontsize',9);
box on
grid on
text(107,28.23,['\bf R=',num2str(R(1,2),'%.2f'),', P<0.001'],'color','k','fontsize',12);
text(164,28.47,'\bf 1929 m','fontsize',12);
title('\bf (b)','fontsize',10);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'FontName','SansSarif');
set(gca,'Fontsize',11); 
set(gca,'linewidth',1.5);
