%code for Figure.12b-e in GMD
%Chuan Xie (xiechuan@sjtu.edu.cn)
clc;
clear all;
%% load grid information from RAS model grid file 
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
load('..\grid_file\mask_shelf.mat');
load('..\grid_file\RAS_depth.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
zice=ncread(grdfilename,'zice');
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
ang=ncread(grdfilename,'angle');
h=ncread(grdfilename,'h');
pm=ncread(grdfilename,'pm');
pn=ncread(grdfilename,'pn');

for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
           lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end  
end
grid_area=(1./pm).*(1./pn);
dz=zw(:,:,2:end)-zw(:,:,1:end-1);

%% plot map
lon_DT=173;
lat_DT=-72.4;
lon_JT=175;
lat_JT=-74;
lon_GCT=182.4;
lat_GCT=-76;
lon_RI=166;
lat_RI=-77.4;

set(gcf,'Position',[100 50 800 550]);
m_proj('lambert','lat',[-78.2 -70],'long',[165 184],'rectbox','on');      
m_pcolor(lon_rho,lat_rho,h);
load('..\NCL_colormap\cmocean_deep.rgb');
colormap(cmocean_deep./255)
hold on
m_contour(lon_rho,lat_rho,h,[500 1000 1500],'color','#4F4F4F','linewidth',0.5);
m_scatter(lon_GCT,lat_GCT,66,'r','filled');
m_scatter(lon_DT,lat_DT,66,'r','filled');
m_scatter(lon_JT,lat_JT,66,'r','filled');
m_scatter(lon_RI,lat_RI,66,'r','filled');
m_text(lon_GCT,lat_GCT+0.1,{'\bf GCT'},'FontSize',11);
m_text(lon_DT+0.1,lat_DT+0.1,{'\bf DT'},'FontSize',11);
m_text(lon_JT,lat_JT+0.1,{'\bf JT'},'FontSize',11);
m_text(lon_RI-2,lat_RI+0.15,{'\bf RI'},'FontSize',11);
m_gshhs_f('patch',[0.5 0.5 0.5],'linewidth',1,'edgecolor','none');
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),5,[0.8 0.8 0.8],'filled');
m_grid('gridcolor','k','linest','none','tickdir','in','linewidth',1.2,'fontsize',10,'xtick',[165,172,180],'yaxisloc','left');
m_text(168,-78,{'ROSS ICE SHELF'},'FontSize',10);
m_text(166,-71.7,{' CAPE';'ADARE'},'FontSize',10);
title('\bf (a)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'FontName','SansSarif');
set(gca,'Fontsize',10); 
set(gca,'linewidth',1.2);


%% region mask
%---------TNB region-----
lon_area=[163,166]; 
lat_area=[-75.5,-74.75];
mask_TNB=nan(1000,1000,32);
for i=1:1000
    for j=1:1000
        for k=1:32
            if mask_rho(i,j)==1&&zice(i,j)==0&&zr(i,j,k)<-800
                if lon_rho(i,j)<=lon_area(2)&&lon_rho(i,j)>=lon_area(1)&&lat_rho(i,j)>=lat_area(1)&&lat_rho(i,j)<=lat_area(2)
                   mask_TNB(i,j,k)=1;
                end
            end
        end
    end
end    


%---------DT region-----
lon_area=[171.5,174.5]; 
lat_area=[-72.67,-72];
mask_DT=nan(1000,1000,32);
for i=1:1000
    for j=1:1000
        for k=1:32
            if mask_rho(i,j)==1&&zice(i,j)==0&&zr(i,j,k)<-500
                if lon_rho(i,j)<=lon_area(2)&&lon_rho(i,j)>=lon_area(1)&&lat_rho(i,j)>=lat_area(1)&&lat_rho(i,j)<=lat_area(2)
                   mask_DT(i,j,k)=1;
                end
            end
        end
    end
end

%---------JT region-----
lon_area=[174.2,176]; 
lat_area=[-74.1,-73.9];
mask_JT=nan(1000,1000,32);
for i=1:1000
    for j=1:1000
        for k=1:32
            if mask_rho(i,j)==1&&zice(i,j)==0&&zr(i,j,k)<-500
                if lon_rho(i,j)<=lon_area(2)&&lon_rho(i,j)>=lon_area(1)&&lat_rho(i,j)>=lat_area(1)&&lat_rho(i,j)<=lat_area(2)
                   mask_JT(i,j,k)=1;
                end
            end
        end
    end
end

%---------GCT region-----
lon_area=[182,182.9]; 
lat_area=[-76.2,-75.8];
mask_GCT=nan(1000,1000,32);
for i=1:1000
    for j=1:1000
        for k=1:32
            if mask_rho(i,j)==1&&zice(i,j)==0&&zr(i,j,k)<-500
                if lon_rho(i,j)<=lon_area(2)&&lon_rho(i,j)>=lon_area(1)&&lat_rho(i,j)>=lat_area(1)&&lat_rho(i,j)<=lat_area(2)
                   mask_GCT(i,j,k)=1;
                end
            end
        end
    end
end

%%
clc
filedir_path='..\Base_simulation_nudging\';
%-------------------------2003.1.27--------------------------
filenum=38;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2003_RAISE=mean(mean(salt(:,:,:,1),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2003): ',num2str(salt_DT_2003_RAISE),' PSU']);
salt_JT_2003_RAISE=mean(mean(salt(:,:,:,1),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2003): ',num2str(salt_JT_2003_RAISE),' PSU']);
salt_GCT_2003_RAISE=mean(mean(salt(:,:,:,1),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2003): ',num2str(salt_GCT_2003_RAISE),' PSU']);
salt_TNB_2003_RAISE=mean(mean(salt(:,:,:,1),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2003): ',num2str(salt_TNB_2003_RAISE),' PSU']);

%--------------------------2004.1.27------------------------
filenum=45;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2004_RAISE=mean(mean(salt(:,:,:,4),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2004): ',num2str(salt_DT_2004_RAISE),' PSU']);
salt_JT_2004_RAISE=mean(mean(salt(:,:,:,4),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2004): ',num2str(salt_JT_2004_RAISE),' PSU']);
salt_GCT_2004_RAISE=mean(mean(salt(:,:,:,4),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2004): ',num2str(salt_GCT_2004_RAISE),' PSU']);
salt_TNB_2004_RAISE=mean(mean(salt(:,:,:,4),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2004): ',num2str(salt_TNB_2004_RAISE),' PSU']);


%-----------------------------2005.1.6-2005.1.31-----------------------------
filenum=52;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2005_RAISE=mean(mean(salt(:,:,:,7:8),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2005): ',num2str(salt_DT_2005_RAISE),' PSU']);
salt_JT_2005_RAISE=mean(mean(salt(:,:,:,7:8),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2005): ',num2str(salt_JT_2005_RAISE),' PSU']);
salt_GCT_2005_RAISE=mean(mean(salt(:,:,:,7:8),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2005): ',num2str(salt_GCT_2005_RAISE),' PSU']);
salt_TNB_2005_RAISE=mean(mean(salt(:,:,:,7:8),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2005): ',num2str(salt_TNB_2005_RAISE),' PSU']);


%------------------------------2006.1.31-----------------------------
filenum=60;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2006_RAISE=mean(mean(salt(:,:,:,1),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2006): ',num2str(salt_DT_2006_RAISE),' PSU']);
salt_JT_2006_RAISE=mean(mean(salt(:,:,:,1),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2006): ',num2str(salt_JT_2006_RAISE),' PSU']);
salt_GCT_2006_RAISE=mean(mean(salt(:,:,:,1),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2006): ',num2str(salt_GCT_2006_RAISE),' PSU']);
salt_TNB_2006_RAISE=mean(mean(salt(:,:,:,1),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2006): ',num2str(salt_TNB_2006_RAISE),' PSU']);


%-------------------------2007.1.27-2007.1.31-------------------------------
filenum=67;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2007_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2007): ',num2str(salt_DT_2007_RAISE),' PSU']);
salt_JT_2007_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2007): ',num2str(salt_JT_2007_RAISE),' PSU']);
salt_GCT_2007_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2007): ',num2str(salt_GCT_2007_RAISE),' PSU']);
salt_TNB_2007_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2007): ',num2str(salt_TNB_2007_RAISE),' PSU']);


%--------------------------2008.1.27-2008.1.31------------------------------
filenum=74;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2008_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2008): ',num2str(salt_DT_2008_RAISE),' PSU']);
salt_JT_2008_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2008): ',num2str(salt_JT_2008_RAISE),' PSU']);
salt_GCT_2008_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2008): ',num2str(salt_GCT_2008_RAISE),' PSU']);
salt_TNB_2008_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2008): ',num2str(salt_TNB_2008_RAISE),' PSU']);


%--------------------------2009.1.25-2009.1.30----------------------------
filenum=81;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2009_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2009): ',num2str(salt_DT_2009_RAISE),' PSU']);
salt_JT_2009_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2009): ',num2str(salt_JT_2009_RAISE),' PSU']);
salt_GCT_2009_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2009): ',num2str(salt_GCT_2009_RAISE),' PSU']);
salt_TNB_2009_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2009): ',num2str(salt_TNB_2009_RAISE),' PSU']);


%--------------------------2010.1.25-2010.1.30-----------------------------
filenum=89;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2010_RAISE=mean(mean(salt(:,:,:,2:3),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2010): ',num2str(salt_DT_2010_RAISE),' PSU']);
salt_JT_2010_RAISE=mean(mean(salt(:,:,:,2:3),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2010): ',num2str(salt_JT_2010_RAISE),' PSU']);
salt_GCT_2010_RAISE=mean(mean(salt(:,:,:,2:3),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2010): ',num2str(salt_GCT_2010_RAISE),' PSU']);
salt_TNB_2010_RAISE=mean(mean(salt(:,:,:,2:3),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2010): ',num2str(salt_TNB_2010_RAISE),' PSU']);


%---------------------------2011.1.25-2011.1.30----------------------------
filenum=96;
filename=[filedir_path,'RAS_avg_00',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2011_RAISE=mean(mean(salt(:,:,:,5:6),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2011): ',num2str(salt_DT_2011_RAISE),' PSU']);
salt_JT_2011_RAISE=mean(mean(salt(:,:,:,5:6),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2011): ',num2str(salt_JT_2011_RAISE),' PSU']);
salt_GCT_2011_RAISE=mean(mean(salt(:,:,:,5:6),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2011): ',num2str(salt_GCT_2011_RAISE),' PSU']);
salt_TNB_2011_RAISE=mean(mean(salt(:,:,:,5:6),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2011): ',num2str(salt_TNB_2011_RAISE),' PSU']);


%---------------------------2012.1.25-2012.1.30---------------------------
filenum=103;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2012_RAISE=mean(mean(salt(:,:,:,8:9),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2012): ',num2str(salt_DT_2012_RAISE),' PSU']);
salt_JT_2012_RAISE=mean(mean(salt(:,:,:,8:9),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2012): ',num2str(salt_JT_2012_RAISE),' PSU']);
salt_GCT_2012_RAISE=mean(mean(salt(:,:,:,8:9),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2012): ',num2str(salt_GCT_2012_RAISE),' PSU']);
salt_TNB_2012_RAISE=mean(mean(salt(:,:,:,8:9),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2012): ',num2str(salt_TNB_2012_RAISE),' PSU']);


%---------------------------2013.1.24-2013.1.29---------------------------
filenum=111;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2013_RAISE=mean(mean(salt(:,:,:,1:2),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2013): ',num2str(salt_DT_2013_RAISE),' PSU']);
salt_JT_2013_RAISE=mean(mean(salt(:,:,:,1:2),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2013): ',num2str(salt_JT_2013_RAISE),' PSU']);
salt_GCT_2013_RAISE=mean(mean(salt(:,:,:,1:2),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2013): ',num2str(salt_GCT_2013_RAISE),' PSU']);
salt_TNB_2013_RAISE=mean(mean(salt(:,:,:,1:2),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2013): ',num2str(salt_TNB_2013_RAISE),' PSU']);


%---------------------------2014.1.24-2014.1.29----------------------------
filenum=118;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2014_RAISE=mean(mean(salt(:,:,:,4:5),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2014): ',num2str(salt_DT_2014_RAISE),' PSU']);
salt_JT_2014_RAISE=mean(mean(salt(:,:,:,4:5),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2014): ',num2str(salt_JT_2014_RAISE),' PSU']);
salt_GCT_2014_RAISE=mean(mean(salt(:,:,:,4:5),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2014): ',num2str(salt_GCT_2014_RAISE),' PSU']);
salt_TNB_2014_RAISE=mean(mean(salt(:,:,:,4:5),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2014): ',num2str(salt_TNB_2014_RAISE),' PSU']);


%------------------------------2015.01.24-2015.1.29----------------------------------
filenum=125;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2015_RAISE=mean(mean(salt(:,:,:,6:8),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2015): ',num2str(salt_DT_2015_RAISE),' PSU']);
salt_JT_2015_RAISE=mean(mean(salt(:,:,:,6:8),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2015): ',num2str(salt_JT_2015_RAISE),' PSU']);
salt_GCT_2015_RAISE=mean(mean(salt(:,:,:,6:8),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2015): ',num2str(salt_GCT_2015_RAISE),' PSU']);
salt_TNB_2015_RAISE=mean(mean(salt(:,:,:,6:8),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2015): ',num2str(salt_TNB_2015_RAISE),' PSU']);


%----------------------------------2016.01.24--------------------------------
filenum=132;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2016_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2016): ',num2str(salt_DT_2016_RAISE),' PSU']);
salt_JT_2016_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2016): ',num2str(salt_JT_2016_RAISE),' PSU']);
salt_GCT_2016_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2016): ',num2str(salt_GCT_2016_RAISE),' PSU']);
salt_TNB_2016_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2016): ',num2str(salt_TNB_2016_RAISE),' PSU']);


%----------------------------------2017.01.28-----------------------------
filenum=140;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2017_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2017): ',num2str(salt_DT_2017_RAISE),' PSU']);
salt_JT_2017_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2017): ',num2str(salt_JT_2017_RAISE),' PSU']);
salt_GCT_2017_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2017): ',num2str(salt_GCT_2017_RAISE),' PSU']);
salt_TNB_2017_RAISE=mean(mean(salt(:,:,:,3:4),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2017): ',num2str(salt_TNB_2017_RAISE),' PSU']);


%-----------------------------------2018.01.28------------------------------
filenum=147;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2018_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2018): ',num2str(salt_DT_2018_RAISE),' PSU']);
salt_JT_2018_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2018): ',num2str(salt_JT_2018_RAISE),' PSU']);
salt_GCT_2018_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2018): ',num2str(salt_GCT_2018_RAISE),' PSU']);
salt_TNB_2018_RAISE=mean(mean(salt(:,:,:,6:7),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2018): ',num2str(salt_TNB_2018_RAISE),' PSU']);


%------------------------------------2019.01.28-----------------------------
filenum=154;
filename=[filedir_path,'RAS_avg_0',num2str(filenum),'.nc'];
salt=ncread(filename,'salt');
salt_DT_2019_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_DT,'all','omitnan');
disp(['salinity in DT (2019): ',num2str(salt_DT_2019_RAISE),' PSU']);
salt_JT_2019_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_JT,'all','omitnan');
disp(['salinity in JT (2019): ',num2str(salt_JT_2019_RAISE),' PSU']);
salt_GCT_2019_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_GCT,'all','omitnan');
disp(['salinity in GCT (2019): ',num2str(salt_GCT_2019_RAISE),' PSU']);
salt_TNB_2019_RAISE=mean(mean(salt(:,:,:,9:10),4).*mask_TNB,'all','omitnan');
disp(['salinity in TNB (2019): ',num2str(salt_TNB_2019_RAISE),' PSU']);


salt_DT_DSW_RAISE=[salt_DT_2003_RAISE;salt_DT_2004_RAISE;salt_DT_2005_RAISE;salt_DT_2006_RAISE;...
               salt_DT_2007_RAISE;salt_DT_2008_RAISE;salt_DT_2009_RAISE;salt_DT_2010_RAISE;...
               salt_DT_2011_RAISE;salt_DT_2012_RAISE;salt_DT_2013_RAISE;salt_DT_2014_RAISE;...
               salt_DT_2015_RAISE;salt_DT_2016_RAISE;salt_DT_2017_RAISE;salt_DT_2018_RAISE;...
               salt_DT_2019_RAISE];

salt_JT_DSW_RAISE=[salt_JT_2003_RAISE;salt_JT_2004_RAISE;salt_JT_2005_RAISE;salt_JT_2006_RAISE;...
               salt_JT_2007_RAISE;salt_JT_2008_RAISE;salt_JT_2009_RAISE;salt_JT_2010_RAISE;...
               salt_JT_2011_RAISE;salt_JT_2012_RAISE;salt_JT_2013_RAISE;salt_JT_2014_RAISE;...
               salt_JT_2015_RAISE;salt_JT_2016_RAISE;salt_JT_2017_RAISE;salt_JT_2018_RAISE;...
               salt_JT_2019_RAISE];

salt_GCT_DSW_RAISE=[salt_GCT_2003_RAISE;salt_GCT_2004_RAISE;salt_GCT_2005_RAISE;salt_GCT_2006_RAISE;...
                salt_GCT_2007_RAISE;salt_GCT_2008_RAISE;salt_GCT_2009_RAISE;salt_GCT_2010_RAISE;...
                salt_GCT_2011_RAISE;salt_GCT_2012_RAISE;salt_GCT_2013_RAISE;salt_GCT_2014_RAISE;...
                salt_GCT_2015_RAISE;salt_GCT_2016_RAISE;salt_GCT_2017_RAISE;salt_GCT_2018_RAISE;...
                salt_GCT_2019_RAISE];

salt_TNB_DSW_RAISE=[salt_TNB_2003_RAISE;salt_TNB_2004_RAISE;salt_TNB_2005_RAISE;salt_TNB_2006_RAISE;...
                salt_TNB_2007_RAISE;salt_TNB_2008_RAISE;salt_TNB_2009_RAISE;salt_TNB_2010_RAISE;...
                salt_TNB_2011_RAISE;salt_TNB_2012_RAISE;salt_TNB_2013_RAISE;salt_TNB_2014_RAISE;...
                salt_TNB_2015_RAISE;salt_TNB_2016_RAISE;salt_TNB_2017_RAISE;salt_TNB_2018_RAISE;...
                salt_TNB_2019_RAISE];

save('..\GMD_2024\data\Figure-12\salt_DSW_RAISE.mat',...
    'salt_DT_DSW_RAISE','salt_JT_DSW_RAISE','salt_GCT_DSW_RAISE','salt_TNB_DSW_RAISE');

%% linear trend
load('..\GMD_2024\data\Figure-12\salt_DSW_RAISE.mat');
line_width=2.8;
dotline_width=2.6;

year_begin=2003;
year_end=2019;
year=year_begin:year_end;
%-------------------------------------------------------------------------
%-----------------------------------DT------------------------------------
input=[ones(size(year')) year'];
[b1,bint,r,rint,stats1]=regress(salt_DT_DSW_RAISE(1:11,1),input(1:11,:));
regress_x1=2003:2014;
regress_y1=regress_x1.*b1(2)+b1(1);
[b2,bint,r,rint,stats2]=regress(salt_DT_DSW_RAISE(12:17,1),input(12:17,:));
regress_x2=2014:2019;
regress_y2=regress_x2.*b2(2)+b2(1);

figure(2)
set(gcf,'Position',[80 60 1200 720]);
ha=tight_subplot(2, 2, [.10 .06], [.08 .08], [.1 .04]);
axes(ha(1));
plot(year,salt_DT_DSW_RAISE,'-o','color','#000000','MarkerFaceColor','#000000','linewidth',line_width);
hold on
plot(regress_x1,regress_y1,'--k','color','#4682B4','LineWidth',dotline_width);
plot(regress_x2,regress_y2,'--k','color','#4682B4','LineWidth',dotline_width);
xlim([year_begin,year_end]);
ylimmin=34.61;
ylimmax=34.8;
ylim([ylimmin,ylimmax]);
ylabel('Salinity [PSU]');
text(2003.5,ylimmin+0.025,[{'\bf Trend=-0.004 (PSU yr^{-1})'};{[' P=0.05']}],...
    'color','#4682B4','fontsize',12);
text(2012,ylimmin+0.15,[{'\bf Trend=0.012 (PSU yr^{-1})'};{[' P<0.01']}],...
    'color','#4682B4','fontsize',12);
% legend({'RAISE','linear trend'},'Location','northwest','NumColumns',3);
text(2004,34.78,'\bf DT','fontsize',18);
title('\bf (b)','fontsize',11);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',2);
set(gca,'fontsize',12);
grid on

%--------------------------------------------------------------------------
%-------------------------------------JT-----------------------------------
input=[ones(size(year')) year'];
[b1,bint,r,rint,stats1]=regress(salt_JT_DSW_RAISE(1:11,1),input(1:11,:));
regress_x1=2003:2014;
regress_y1=regress_x1.*b1(2)+b1(1);
[b2,bint,r,rint,stats2]=regress(salt_JT_DSW_RAISE(12:17,1),input(12:17,:));
regress_x2=2014:2019;
regress_y2=regress_x2.*b2(2)+b2(1);

axes(ha(2));
plot(year,salt_JT_DSW_RAISE,'-o','color','#000000','MarkerFaceColor','#000000','linewidth',line_width);
hold on
plot(regress_x1,regress_y1,'--k','color','#4682B4','LineWidth',dotline_width);
plot(regress_x2,regress_y2,'--k','color','#4682B4','LineWidth',dotline_width);
xlim([year_begin,year_end]);
ylimmin=34.66;
ylimmax=34.85;
ylim([ylimmin,ylimmax]);
% ylabel('Salinity [PSU]');
text(2003.5,ylimmin+0.045,[{'\bf Trend=-0.007 (PSU yr^{-1})'};{[' P<0.01']}],...
    'color','#4682B4','fontsize',12);
text(2012,ylimmin+0.156,[{'\bf Trend=0.017 (PSU yr^{-1})'};{[' P=0.05']}],...
    'color','#4682B4','fontsize',12);
% legend({'RAISE','linear trend'},'Location','northwest','NumColumns',3);
text(2004,34.83,'\bf JT','fontsize',18);
title('\bf (c)','fontsize',11);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',2);
set(gca,'fontsize',12);
grid on

%---------------------------------------------------------------------------
%------------------------------------GCT------------------------------------
input=[ones(size(year')) year'];
[b1,bint,r,rint,stats1]=regress(salt_GCT_DSW_RAISE(1:11,1),input(1:11,:));
regress_x1=2003:2014;
regress_y1=regress_x1.*b1(2)+b1(1);
[b2,bint,r,rint,stats2]=regress(salt_GCT_DSW_RAISE(12:17,1),input(12:17,:));
regress_x2=2014:2019;
regress_y2=regress_x2.*b2(2)+b2(1);

axes(ha(3));
plot(year,salt_GCT_DSW_RAISE,'-o','color','#000000','MarkerFaceColor','#000000','linewidth',line_width);
hold on
plot(regress_x1,regress_y1,'--k','color','#4682B4','LineWidth',dotline_width);
plot(regress_x2,regress_y2,'--k','color','#4682B4','LineWidth',dotline_width);
xlim([year_begin,year_end]);
ylimmin=34.64;
ylimmax=34.82;
ylim([ylimmin,ylimmax]);
ylabel('Salinity [PSU]');
text(2003.5,ylimmin+0.025,[{'\bf Trend=-0.006 (PSU yr^{-1})'};{[' P<0.01']}],...
    'color','#4682B4','fontsize',12);
text(2012,ylimmin+0.15,[{'\bf Trend=0.017 (PSU yr^{-1})'};{[' P=0.05']}],...
    'color','#4682B4','fontsize',12);
% legend({'RAISE','linear trend'},'Location','northwest','NumColumns',3);
text(2004,34.8,'\bf GCT','fontsize',18);
title('\bf (d)','fontsize',11);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',2);
set(gca,'fontsize',12);
grid on

%-----------------------------------------------------------------------------
%------------------------------------TNB--------------------------------------
input=[ones(size(year')) year'];
[b1,bint,r,rint,stats1]=regress(salt_TNB_DSW_RAISE(1:11,1),input(1:11,:));
regress_x1=2003:2014;
regress_y1=regress_x1.*b1(2)+b1(1);
[b2,bint,r,rint,stats2]=regress(salt_TNB_DSW_RAISE(12:17,1),input(12:17,:));
regress_x2=2014:2019;
regress_y2=regress_x2.*b2(2)+b2(1);

axes(ha(4));
plot(year,salt_TNB_DSW_RAISE,'-o','color','#000000','MarkerFaceColor','#000000','linewidth',line_width);
hold on
plot(regress_x1,regress_y1,'--k','color','#4682B4','LineWidth',dotline_width);
plot(regress_x2,regress_y2,'--k','color','#4682B4','LineWidth',dotline_width);
xlim([year_begin,year_end]);
ylimmin=34.75;
ylimmax=35;
ylim([ylimmin,ylimmax]);
% ylabel('Salinity [PSU]');
text(2003.5,ylimmin+0.055,[{'\bf Trend=-0.008 (PSU yr^{-1})'};{[' P<0.01']}],...
    'color','#4682B4','fontsize',12);
text(2012,ylimmin+0.19,[{'\bf Trend=0.019 (PSU yr^{-1})'};{[' P<0.01']}],...
    'color','#4682B4','fontsize',12);
% legend({'RAISE','linear trend'},'Location','northwest','NumColumns',3);
text(2004,34.975,'\bf TNB','fontsize',18);
title('\bf (e)','fontsize',11);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',2);
set(gca,'fontsize',12);
grid on


