%code for Figure.13 in GMD manuscript
%Chuan Xie (xiechuan@sjtu.edu.cn)
clc;
clear all;   

%% load ice shelf melt rate data from RAS model output files
RAS_data_dirname_CTRL=['..\Base_simulation_nudging\'];
file_begin=38;
file_end=155;

%-------------------------------CTRL-----------------------------
index=1;
for filenum=file_begin:file_end
    disp(filenum)
    filename=[RAS_data_dirname_CTRL,'RAS_avg_0',num2str(filenum,'%03d'),'.nc'];
    mr_tmp=ncread(filename,'melt_rate');
    mr_RAS(:,:,index)=mean(mr_tmp,3);
    index=index+1;
    clear mr_tmp
end
mr_CTRL=mean(mr_RAS,3,'omitnan').*(365*24*60*60); clear mr_RAS

save('..\GMD_2024\data\Figure-13\melt_rate_CTRL.mat','mr_CTRL');

%% load grid information from RAS model grid file 
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
load('..\grid_file\mask_shelf.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
zice=ncread(grdfilename,'zice');
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
ang=ncread(grdfilename,'angle');
h=ncread(grdfilename,'h');
pm=ncread(grdfilename,'pm');
pn=ncread(grdfilename,'pn');

for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end
end
grid_area=(1./pm).*(1./pn);
for i=1:1000
    for j=1:1000
        if zice(i,j)==0
            grid_area(i,j)=NaN;
            mr_CTRL(i,j)=NaN;
        end
    end
end


%% Calculate each ice shelf melt rate (Gt/yr)
rho_freshwater=1000;
clc
%Ross Ice shelf
xindex=200:1:600;
yindex=1:1:300;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
RIS_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Ross Ice Shelf melt rate (CTRL):  ',num2str(RIS_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%-----------------Total Amundsen Ice Shelf-----------
xindex=640:1:1000;
yindex=1:1:1000;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Amundsen_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Total Amundsen Ice Shelf Ice Shelf melt rate:  ',num2str(Amundsen_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%------------------------Getz Ice Shelf------------------
xindex=640:1:805;
yindex=400:1:600;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Getz_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Getz Ice Shelf melt rate:  ',num2str(Getz_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%-----------------------Pine island ice Shelf-------------------
xindex=900:1:1000;
yindex=400:1:500;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Pine_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Pine island Ice Shelf melt rate:  ',num2str(Pine_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%--------------------------Dotson ice Shelf------------------------
xindex=805:1:832;
yindex=448:1:500;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Dotson_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Dotson Ice Shelf melt rate:  ',num2str(Dotson_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%-----------------------------Crosson ice Shelf------------------------
xindex=829:1:850;
yindex=400:1:500;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Crosson_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Crosson Ice Shelf melt rate:  ',num2str(Crosson_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%--------------------------------Thwaites ice Shelf------------------------
xindex=850:1:900;
yindex=400:1:500;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Thwaites_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Thwaites Ice Shelf melt rate:  ',num2str(Thwaites_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%-------------------------------Cosgrave ice Shelf--------------------------
xindex=900:1:1000;
yindex=500:1:540;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Cosgrave_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Cosgrave Ice Shelf melt rate:  ',num2str(Cosgrave_meltrate_CTRL),'  Gt/yr']);

disp('    ')
%-------------------------------Abbot ice Shelf--------------------------
xindex=900:1:1000;
yindex=542:1:700;
total_area=sum(grid_area(xindex,yindex),'all','omitnan');
% unit: Gt/yr
Abbot_meltrate_CTRL=(sum(mr_CTRL(xindex,yindex).*grid_area(xindex,yindex),'all','omitnan').*rho_freshwater)/1e12;
disp(['Abbot Ice Shelf melt rate:  ',num2str(Abbot_meltrate_CTRL),'  Gt/yr']);

%% melt rate
%  unit: Gt/yr
Obsver_01=[47.7, 144.9, 83.7, 97.5, 101.2, 8.5, 435.8]'; %Rignot et al. 2013
Obsver_02=[34,   136,   78,   69,   95,    11,  389]'; %Depoorter et al. 2013
Obsver_03=[27,   149,   72,   62,   78,    9,  370]'; %Liu et al. 2015
err_01  = [34   14  8  7  8  2  39]; 
err_02  = [25  23  7  18  14  3  65];
err_03  = [22  16  5  19  8  1  49];
err_04  = [0  0  0  0  0  0  0];
x1=1:7;

figure(2)
set(gcf,'Position',[80 60 800 470]);
name = categorical({'Ross','Getz','Dotson+Crosson',...
                     'Thwaites','Pine island','Cosgrove','Total Amundsen Sea'});
name = reordercats(name,{'Ross','Getz','Dotson+Crosson',...
                    'Thwaites','Pine island','Cosgrove','Total Amundsen Sea'});
Melt_rate=[Obsver_01(1) Obsver_02(1) Obsver_03(1) RIS_meltrate_CTRL;...
           Obsver_01(2) Obsver_02(2) Obsver_03(2) Getz_meltrate_CTRL;...
           Obsver_01(3) Obsver_02(3) Obsver_03(3) Dotson_meltrate_CTRL+Crosson_meltrate_CTRL;...
           Obsver_01(4) Obsver_02(4) Obsver_03(4) Thwaites_meltrate_CTRL;...
           Obsver_01(5) Obsver_02(5) Obsver_03(5) Pine_meltrate_CTRL;...
           Obsver_01(6) Obsver_02(6) Obsver_03(6) Cosgrave_meltrate_CTRL;...           
           Obsver_01(7) Obsver_02(7) Obsver_03(7) Amundsen_meltrate_CTRL-Abbot_meltrate_CTRL];
errhigh=[err_01' err_02' err_03' err_04'];
errlow=[err_01' err_02' err_03' err_04'];

b=bar(name,Melt_rate);
set(b(1),'FaceColor','#7DD2F6','EdgeColor','#7DD2F6');
set(b(2),'Facecolor','#B688BC','EdgeColor','#B688BC');
set(b(3),'Facecolor','#3E58A6','EdgeColor','#3E58A6');
set(b(4),'Facecolor','#57485E','EdgeColor','#57485E');
hold on
x=[x1'-0.27 x1'-0.09 x1'+0.09 x1'+0.26];
er = errorbar(x,Melt_rate,errlow,errhigh,"LineStyle","none",'LineWidth',1.0,'Color','k');    

ylabel('Ice shelf basal mass loss [Gt/yr]');
ylim([0 580])
set(gca,'fontsize',14);
set(gca,'linewidth',1.4);
legend({'Rignot et al. (2013)','Depoorter et al. (2013)','Liu et al. (2015)','RAISE'},'Location','northwest');



