%code for Figure.14 in GMD manuscript
%Chuan Xie (xiechuan@sjtu.edu.cn)
clc;
clear all;    

%% load grid information from RAS model grid file
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
load('..\grid_file\RAS_depth.mat');
load('..\grid_file\mask_shelf.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
zice=ncread(grdfilename,'zice');
h=ncread(grdfilename,'h');
pm=ncread(grdfilename,'pm');
pn=ncread(grdfilename,'pn');
grid_area=1./(pm.*pn);
dz=zw(:,:,2:end)-zw(:,:,1:end-1);
RAS_volume=grid_area.*dz;
for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end 
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end
end

%Calculates sea pressure from depth 
for k=1:32
   pr(:,:,k) = gsw_p_from_z(zr(:,:,k),lat_rho);
end

%% load data
file_begin=75;
file_end=80;
%--------------------------------CTRL----------------------------------
filedir='..\Base_simulation_nudging\';
index=1;
for filenum=file_begin:file_end
    filename=[filedir,'RAS_avg_0',num2str(filenum,'%03d'),'.nc'];
    temp_tmp_CTRL(:,:,:,index)=nanmean(ncread(filename,'temp'),4);
    salt_tmp_CTRL(:,:,:,index)=nanmean(ncread(filename,'salt'),4);
    index=index+1;
    disp(filenum)
end
temp_CTRL=mean(temp_tmp_CTRL,4); clear temp_tmp_CTRL
salt_CTRL=mean(salt_tmp_CTRL,4); clear salt_tmp_CTRL
for k=1:32
   gamma_CTRL(:,:,k)=gamma_GP_from_SP_pt(salt_CTRL(:,:,k),temp_CTRL(:,:,k),pr(:,:,k),lon_rho,lat_rho);
end

save('..\GMD_2024\data\Figure-14\Mean_TSD_CTRL.mat',...
    'salt_CTRL','temp_CTRL','gamma_CTRL');

%-----------------------------nudging_Melt---------------------------------
filedir='..\Base_simulation_nudging_Melt\';
index=1;
for filenum=file_begin:file_end
    filename=[filedir,'RAS_avg_0',num2str(filenum,'%03d'),'.nc'];
    temp_tmp_MeltH(:,:,:,index)=nanmean(ncread(filename,'temp'),4);
    salt_tmp_MeltH(:,:,:,index)=nanmean(ncread(filename,'salt'),4);
    index=index+1;
    disp(filenum)
end
temp_MeltH=mean(temp_tmp_MeltH,4); clear temp_tmp_MeltH
salt_MeltH=mean(salt_tmp_MeltH,4); clear salt_tmp_MeltH
for k=1:32
   gamma_MeltH(:,:,k)=gamma_GP_from_SP_pt(salt_MeltH(:,:,k),temp_MeltH(:,:,k),pr(:,:,k),lon_rho,lat_rho);
end


save('..\GMD_2024\data\Figure-14\Mean_TSD_MeltH.mat',...
    'salt_MeltH','temp_MeltH','gamma_MeltH');


%% Calculate DSW volume over shelf in the Ross Sea
load('..\GMD_2024\data\Figure-14\Mean_TSD_CTRL.mat');
load('..\GMD_2024\data\Figure-14\Mean_TSD_MeltH.mat');

gamma_threshold=28.27; 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-----------------------------------CTRL----------------------------------%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DSW_volume_mask=zeros(1000,1000,32);
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==1&&zice(i,j)==0
            for k=1:32
                if gamma_CTRL(i,j,k)>=gamma_threshold
                    DSW_volume_mask(i,j,k)=1;
                else 
                    DSW_volume_mask(i,j,k)=0;
                end
            end
        end
    end
end     
%DSW layer thickness
DSW_layer_CTRL=nansum(dz.*DSW_volume_mask,3);
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            DSW_layer_CTRL(i,j)=NaN;
        end
    end
end

DSW_volume_mask_RS=zeros(1000,1000,32);
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==1&&zice(i,j)==0&&mask_rossshelf(i,j)==1
            for k=1:32
                if gamma_CTRL(i,j,k)>=gamma_threshold
                    DSW_volume_mask_RS(i,j,k)=1;
                else 
                    DSW_volume_mask_RS(i,j,k)=0;
                end
            end
        end
    end
end     
Vdsw_total_CTRL=sum(DSW_volume_mask_RS.*RAS_volume,'all','omitnan')./1e13;   
disp(Vdsw_total_CTRL)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-----------------------------------MeltH---------------------------------%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DSW_volume_mask=zeros(1000,1000,32);
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==1&&zice(i,j)==0
            for k=1:32
                if gamma_MeltH(i,j,k)>=gamma_threshold
                    DSW_volume_mask(i,j,k)=1;
                else 
                    DSW_volume_mask(i,j,k)=0;
                end
            end
        end
    end
end     
%DSW layer thickness
DSW_layer_MeltH=nansum(dz.*DSW_volume_mask,3);
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            DSW_layer_MeltH(i,j)=NaN;
        end
    end
end

DSW_volume_mask_RS=zeros(1000,1000,32);
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==1&&zice(i,j)==0&&mask_rossshelf(i,j)==1
            for k=1:32
                if gamma_MeltH(i,j,k)>=gamma_threshold
                    DSW_volume_mask_RS(i,j,k)=1;
                else 
                    DSW_volume_mask_RS(i,j,k)=0;
                end
            end
        end
    end
end     
Vdsw_total_MeltH=sum(DSW_volume_mask_RS.*RAS_volume,'all','omitnan')./1e13;   
disp(Vdsw_total_MeltH)

filename='..\GMD_2024\data\Figure-14\DSW_layer_thickness.mat';
save(filename,'DSW_layer_CTRL','DSW_layer_MeltH');



%% ŵƽ
filename='..\GMD_2024\data\Figure-14\DSW_layer_thickness.mat';
load(filename);

Diff_DSW_layer_MeltH=DSW_layer_MeltH-DSW_layer_CTRL;
Diff_DSW_layer_MeltH_smooth01=zeros(1000,1000);

for i=2:999
    for j=2:999
    Diff_DSW_layer_MeltH_smooth01(i,j)=(Diff_DSW_layer_MeltH(i,j)+Diff_DSW_layer_MeltH(i-1,j)+...
        Diff_DSW_layer_MeltH(i+1,j)+Diff_DSW_layer_MeltH(i,j-1)+Diff_DSW_layer_MeltH(i,j+1)+...
        Diff_DSW_layer_MeltH(i-1,j-1)+Diff_DSW_layer_MeltH(i-1,j+1)+Diff_DSW_layer_MeltH(i+1,j+1)+...
        Diff_DSW_layer_MeltH(i+1,j-1))./9;
    end
end


%% plot
%-------------------------------DSW layer------------------------------

figure(1)
set(gcf,'Position',[80 140 480 450]);
ha=tight_subplot(1, 1, [.04 .02], [.22 .08], [.12 .05]);
axes(ha(1));
m_proj('Equidistant Cylindrical','lat',[-79 -66],'long',[160 210]);    
m_pcolor(lon_rho,lat_rho,DSW_layer_CTRL);
load('D:\MATLAB\NCL_colormap\precip3_16lev.rgb');
colormap(precip3_16lev./255)
caxis([0,600]);
title('\bf(a)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
m_contour(lon_rho,lat_rho,h,[500,1000],'color','#4F4F4F','linewidth',0.4);
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),5,[0.85 0.85 0.85],'filled');
m_gshhs_f('color','k','linewidth',0.8);
m_line([180 180],[-82.92 -77.9],'color',[.85 .85 .85],'linewidth',2);
m_text(161,-72,{'\bf CTRL'},'FontSize',13);
m_grid('gridcolor','k','linest','none','tickdir','in','linewidth',1.5,'fontsize',12,'xtick',5,'yaxisloc','left');
hold on
M=m_shaperead('ne_10m_coastline'); 
for k=1:length(M.ncst)
     if M.ncst{k}(:,1)<0
         M.ncst{k}(:,1)=M.ncst{k}(:,1)+360;
     end
     m_line(M.ncst{k}(:,1),M.ncst{k}(:,2),'color','k','linewi',0.8); 
end
%-----------colorbar--------------
ch=colorbar('southoutside','fontsize',12);
set(get(ch,'label'),'string','DSW/AABW layer thinkness [m]','fontsize',12) 
pos3=set(ch,'Position',[0.31,0.12,0.45,0.025]);  

figure(2)
set(gcf,'Position',[80 140 480 450]);
ha=tight_subplot(1, 1, [.04 .02], [.22 .08], [.12 .05]);
axes(ha(1));
m_proj('Equidistant Cylindrical','lat',[-79 -66],'long',[160 210]);    
m_pcolor(lon_rho,lat_rho,Diff_DSW_layer_MeltH_smooth01);
load('D:\MATLAB\NCL_colormap\GMT_polar.rgb');  
colormap(GMT_polar)
caxis([-100,100]);
title('\bf(b)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
m_contour(lon_rho,lat_rho,h,[500,1000],'color','#4F4F4F','linewidth',0.4);
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),5,[0.85 0.85 0.85],'filled');
m_gshhs_f('color','k','linewidth',0.8);
m_line([180 180],[-82.92 -77.9],'color',[.85 .85 .85],'linewidth',2);
% m_text(168,-78.35,{'Ross Ice Shelf'},'FontSize',11);
m_text(160.9,-72,{'\bf Melt+'},'FontSize',13);
m_grid('gridcolor','k','linest','none','tickdir','in','linewidth',1.5,'fontsize',12,'xtick',5,'yticklabels',[]);
hold on
M=m_shaperead('ne_10m_coastline'); 
for k=1:length(M.ncst)
     if M.ncst{k}(:,1)<0
         M.ncst{k}(:,1)=M.ncst{k}(:,1)+360;
     end
     m_line(M.ncst{k}(:,1),M.ncst{k}(:,2),'color','k','linewi',0.8); 
end

%-----------colorbar--------------
ch=colorbar('southoutside','fontsize',12);
set(get(ch,'label'),'string','Change in DSW/AABW layer thickness [m]','fontsize',12);
pos3=set(ch,'Position',[0.31,0.12,0.45,0.025]);  


