% Figure.1 in the manuscript
clc;
clear all;

%% load RAISE model grid info
grdfilename='..\RAS_grd.nc';
load('..\ice_shelf\iceshelf_land_line_and_mask.mat');
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end
h=ncread(grdfilename,'h');
zice=ncread(grdfilename,'zice');
mask_u=ncread(grdfilename,'mask_u');
mask_v=ncread(grdfilename,'mask_v');
mask_psi=ncread(grdfilename,'mask_psi');

for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
          h(i,j,:)=NaN;
        end
    end
end


lon_DT=173;
lat_DT=-72.4;
lon_JT=175;
lat_JT=-74;
lon_GCT=182.4;
lat_GCT=-76;
lon_RI=166;
lat_RI=-77.4;
lon_TNB=164.523;
lat_TNB=-75.13338;
lat_mooring_CA1=-71.4597;
lon_mooring_CA1=172.3042; 
lat_mooring_CA2=-71.4270;
lon_mooring_CA2=172.3850; 


%% plot research area map
set(gcf,'position',[60 60 1250 600])
m_proj('albers equal-area','lat',[-84.2 -64.9],'lon',[161 267],'rectbox','on');      
m_pcolor(lon_rho,lat_rho,-h);
load('D:\MATLAB\NCL_colormap\cmocean_deep.rgb');
colormap(flipud(cmocean_deep./255))
caxis([-5000,0])
hold on
% m_contour(lon_rho,lat_rho,-h,[-500,-1000,-3000],'color','#4F4F4F','linewidth',0.8);

m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
% m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),3,[0.85 0.85 0.85],'filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
grid_index=[1:15:1000 1000];
m_line(lon_rho(grid_index,grid_index),lat_rho(grid_index,grid_index),'linewi',0.5,'color',[0.5 0.5 0.5]);
m_line(lon_rho(grid_index,grid_index)',lat_rho(grid_index,grid_index)','linewi',0.5,'color',[0.5 0.5 0.5]);
m_scatter(lon_RI,lat_RI,50,'r','filled','o');
m_scatter(lon_JT,lat_JT,50,'r','filled','o');
m_grid('gridcolor','k','tickdir','in','xtick',8,'ytick',6,'linewidth',2,'fontsize',12,'xaxisloc','top');

filename='I:\RAISE_model\Model_validation\temp_salt\MEOP-CTD\AUSTRALIA\DATA_ncARGO_interp\ct64-M053-09_interp_prof.nc';
LAT_meop=ncread(filename,'LATITUDE');
LONG_meop=ncread(filename,'LONGITUDE');
section_location=165:220;   %time:03/10/2010-03/25/2010
% load('G:\code\location_nbp0702.mat');
m_scatter(LONG_meop(section_location,1),LAT_meop(section_location,1),16,[255 215 0]./255,'filled');
m_scatter(lon_GCT,lat_GCT,66,'b','filled');
m_scatter(lon_DT,lat_DT,66,'b','filled');
m_scatter(lon_JT,lat_JT,66,'b','filled');
m_scatter(lon_RI,lat_RI,66,'m','filled');
m_scatter(lon_TNB,lat_TNB,66,'r','filled');
m_scatter(lon_mooring_CA1,lat_mooring_CA1,66,'r','filled');
m_scatter(lon_mooring_CA2+0.3,lat_mooring_CA2,66,'r','filled');

m_text(lon_GCT,lat_GCT+0.1,{'\bf GCT'},'FontSize',11);
m_text(lon_DT+0.3,lat_DT+0.1,{'\bf DT'},'FontSize',11);
m_text(lon_JT+0.21,lat_JT+0.1,{'\bf JT'},'FontSize',11);
m_text(lon_RI,lat_RI+1.05,{'\bf RI'},'FontSize',11);
m_text(lon_TNB+1,lat_TNB+0.55,{'\bf TNB'},'FontSize',11);
m_text(168.3,-70.2,{'\bf CA1'},'FontSize',11);
m_text(171.0,-69.95,{'\bf CA2'},'FontSize',11);
m_text(168,-79.25,'Ross Ice Shelf','fontsize',12);
m_text(184,-70,'\bf Ross Sea','color','w','fontsize',16);
m_text(230,-70.5,'\bf Amundsen Sea','color','w','fontsize',16);
m_text(164,-71.3,{' Cape';'Adare'},'FontSize',10);
m_text(232,-75.2,'Getz','fontsize',10);
m_text(260,-75.9,'Pine','fontsize',10);
m_text(244,-75.5,'Dot','fontsize',10);
m_text(248,-75.8,'Cro','fontsize',10);
m_text(253,-75.8,'Thw','fontsize',10);
m_text(264,-74,'Abb','fontsize',10);
m_text(259,-74.2,'Cos','fontsize',10);

% %colorbar
ch=colorbar;
ch.Location = 'westoutside';
ch.LineWidth = 1.5;
ch.FontSize = 12;
set(get(ch,'label'),'string','Depth [m]');




