% Figure.3 in the manuscript
clc;
clear all;

%% load grid information from RAS model grid file
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
load('..\grid_file\RAS_depth.mat');
load('..\grid_file\mask_shelf.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
zice=ncread(grdfilename,'zice');
h=ncread(grdfilename,'h');
pm=ncread(grdfilename,'pm');
pn=ncread(grdfilename,'pn');
grid_area=(1./pm).*(1./pn);

dz=zw(:,:,2:end)-zw(:,:,1:end-1);
RAS_volume=grid_area.*dz;
for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end 
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end
end

%% load sea ice data from RAS model output files
amsr_filename='..\Model_validation\SIC\AMSR_sic_rawdata\';
sic_obs_monthly=zeros(1000,1000,12);
year_begin=2003;
year_end=2018;
for iyear=year_begin:year_end
    filename=[amsr_filename,'sic_AMSR_RAS_',num2str(iyear),'.mat'];
    load(filename);
    sic_obs_monthly=sic_obs_monthly+sic_AMSR_monthly;
end
sic_obs_total=sic_obs_monthly./(year_end-year_begin+1);
  
sic_AMSR_seasonal(:,:,1)=mean(sic_obs_total(:,:,[1,2,12]),3);
sic_AMSR_seasonal(:,:,2)=mean(sic_obs_total(:,:,[3,4,5]),3);
sic_AMSR_seasonal(:,:,3)=mean(sic_obs_total(:,:,[6,7,8]),3);
sic_AMSR_seasonal(:,:,4)=mean(sic_obs_total(:,:,[9,10,11]),3);

%% ----CTRL-----
RasDataDirname='..\Base_simulation_nudging\';
variablename='aice';
year_begin=2003;
year_end=2018;
t=1;
for year=year_begin:year_end
    aice_son_RAISE(:,:,t)=GetSeasonalData(year,1,variablename,RasDataDirname);
    aice_djf_RAISE(:,:,t)=GetSeasonalData(year,2,variablename,RasDataDirname);
    aice_mam_RAISE(:,:,t)=GetSeasonalData(year,3,variablename,RasDataDirname);
    aice_jja_RAISE(:,:,t)=GetSeasonalData(year,4,variablename,RasDataDirname);
    t=t+1;
end
aice_son_RAISE_mean=mean(aice_son_RAISE,3).*100;
aice_djf_RAISE_mean=mean(aice_djf_RAISE,3).*100;
aice_mam_RAISE_mean=mean(aice_mam_RAISE,3).*100;
aice_jja_RAISE_mean=mean(aice_jja_RAISE,3).*100;

save('..\GMD_2024\data\Figure-3\aice_seasonal_RAISE.mat',...
    'aice_son_RAISE_mean','aice_djf_RAISE_mean','aice_mam_RAISE_mean','aice_jja_RAISE_mean');

%% 
load('..\GMD_2024\data\Figure-3\aice_seasonal_RAISE.mat')
rsearch_area_lat=[-79 -65.5];
rsearch_area_lon=[160 268];

figure(1)   
set(gcf,'Position',[80 60 1080 390]);
ha=tight_subplot(2, 3, [.01 .01], [.08 .04], [.05 .09]);
% ------------------------------------AMSR-----------------------------------
axes(ha(1));
m_proj('Equidistant Cylindrical','lat',rsearch_area_lat,'long',rsearch_area_lon);      
m_pcolor(lon_rho,lat_rho,sic_AMSR_seasonal(:,:,2));
colormap(flip(othercolor('Spectral10',20)))
caxis([0,100]);
hold on 
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),3,[0.8 0.8 0.8],'filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','xtick',5,'linest','none','tickdir','in','ytick', ...
    [-66 -70 -74 -78],'xticklabels',[],'linewidth',1.5,'fontsize',12);
m_text(225,-77,'\bf MAM  (AMSR)','color','k','fontsize',12);
title('\bf (a)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';

axes(ha(2));
m_proj('Equidistant Cylindrical','lat',rsearch_area_lat,'long',rsearch_area_lon);   
m_pcolor(lon_rho,lat_rho,sic_AMSR_seasonal(:,:,3));
colormap(flip(othercolor('Spectral10',20)))
caxis([0,100]);
hold on 
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),3,[0.8 0.8 0.8],'filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','xtick',5,'linest','none','tickdir','in','ytick', ...
    [-66 -70 -74 -78],'xticklabels',[],'yticklabels',[],'linewidth',1.5,'fontsize',12);
m_text(225,-77,'\bf JJA  (AMSR)','color','k','fontsize',12);
title('\bf (b)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';

axes(ha(3));
m_proj('Equidistant Cylindrical','lat',rsearch_area_lat,'long',rsearch_area_lon);    
m_pcolor(lon_rho,lat_rho,sic_AMSR_seasonal(:,:,4));
colormap(flip(othercolor('Spectral10',20)))
caxis([0,100]);
hold on 
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),3,[0.8 0.8 0.8],'filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','xtick',5,'linest','none','tickdir','in','ytick', ...
    [-66 -70 -74 -78],'xticklabels',[],'yticklabels',[],'linewidth',1.5,'fontsize',12);
m_text(225,-77,'\bf SON  (AMSR)','color','k','fontsize',12);
title('\bf (c)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';


% ------------------------------------RAISE-----------------------------------
axes(ha(4));
m_proj('Equidistant Cylindrical','lat',rsearch_area_lat,'long',rsearch_area_lon);  
m_pcolor(lon_rho,lat_rho,aice_mam_RAISE_mean);
colormap(flip(othercolor('Spectral10',20)))
caxis([0,100]);
hold on 
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),3,[0.8 0.8 0.8],'filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','xtick',5,'linest','none','tickdir','in','ytick', ...
    [-66 -70 -74 -78],'linewidth',1.5,'fontsize',12);
m_text(225,-77,'\bf MAM  (RAISE)','color','k','fontsize',12);
title('\bf (d)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';

axes(ha(5));
m_proj('Equidistant Cylindrical','lat',rsearch_area_lat,'long',rsearch_area_lon);     
m_pcolor(lon_rho,lat_rho,aice_jja_RAISE_mean);
colormap(flip(othercolor('Spectral10',20)))
caxis([0,100]);
hold on 
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),3,[0.8 0.8 0.8],'filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','xtick',5,'linest','none','tickdir','in','ytick', ...
    [-66 -70 -74 -78],'yticklabels',[],'linewidth',1.5,'fontsize',12);
m_text(225,-77,'\bf JJA  (RAISE)','color','k','fontsize',12);
title('\bf (e)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';

axes(ha(6));
m_proj('Equidistant Cylindrical','lat',rsearch_area_lat,'long',rsearch_area_lon);   
m_pcolor(lon_rho,lat_rho,aice_son_RAISE_mean);
% colormap(user_colormap)
colormap(flip(othercolor('Spectral10',20)))
caxis([0,100]);
hold on 
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),3,[0.8 0.8 0.8],'filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','xtick',5,'linest','none','tickdir','in','ytick', ...
    [-66 -70 -74 -78],'yticklabels',[],'linewidth',1.5,'fontsize',12);
m_text(225,-77,'\bf SON  (RAISE)','color','k','fontsize',12);
title('\bf (f)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';

%-----total colorbar-------
ch1=colorbar('eastoutside','fontsize',13);
set(get(ch1,'label'),'string','Sea ice concentration [%]','fontsize',13);
pos1=set(ch1,'Position', [0.92,0.23,0.012,0.56]);  


%% load sea ice concentration data
RAS_data_dirname='..\Base_simulation_nudging\';
savedirname='..\GMD_2024\data\Figure-3\';

for year=2003:2018 
    disp(year)
    for imonth=1:12
        aice_RAISE_monthly(:,:,imonth)=GetMonthlyData(year,imonth,'aice',RAS_data_dirname);
    end
    aice_RAISE_annual=mean(aice_RAISE_monthly,3);
    save([savedirname,'aice_RAISE_monthly_',num2str(year),'.mat'],'aice_RAISE_monthly');
    save([savedirname,'aice_RAISE_annual_',num2str(year),'.mat'],'aice_RAISE_annual');    
end


%% interannual variation-monthly
clc
year_begin=2003;  
year_end=2018;
mask_icearea=zeros(1000,1000);
for i=1:1000
    for j=1:1000
      if mask_rho(i,j)==1&&zice(i,j)==0
          mask_icearea(i,j)=1;
      end
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%---------------------------AMSR-annual-----------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
total_month=1;
iyear=1;
for year=year_begin:year_end
   matfilename=['..\Model_validation\SIC\AMSR_sic_rawdata\sic_AMSR_RAS_',num2str(year),'.mat'];
   load(matfilename);
   for imonth=1:12
       Aice_AMSR(total_month)=sum(sum((sic_AMSR_monthly(:,:,imonth)./100).*grid_area.*mask_icearea,'omitnan'));
       total_month=total_month+1;
   end
   iyear=iyear+1;
end
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%---------------------------RAISE-annual-------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
total_month=1;
iyear=1;
for year=year_begin:year_end
   matfilename=['..\GMD_2024\data\Figure-3\aice_RAISE_monthly_',num2str(year),'.mat'];
   load(matfilename);
   for imonth=1:12
       Aice_RAISE(total_month)=sum(sum((aice_RAISE_monthly(:,:,imonth)).*grid_area.*mask_icearea,'omitnan'));
       total_month=total_month+1;
   end
   iyear=iyear+1;
end

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%-------------------------------画曲线对比图-------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[R1,P1]=corrcoef(Aice_AMSR,Aice_RAISE);

figure(1)
set(gcf,'Position',[80 160 1300 380]);
total_year=(year_end-year_begin+1);
Tmonth=1:total_year*12;
plot(Tmonth,Aice_AMSR./1e12,':','color','#000000','MarkerFaceColor','#000000','linewidth',3);
hold on
plot(Tmonth,Aice_RAISE./1e12,'color','#000000','MarkerFaceColor','#000000','linewidth',3);
ylabel('Sea Ice Area [\times 10^{6} km^{2}]','fontsize',14);
text(150,4.8,['\bf R= ',num2str(roundn(R1(1,2),-2),'%4.2f'),...
    ', P<0.0001'],'color','k','fontsize',16);
grid on
ylim([0 5.2]);
xlim([1 Tmonth(end)]);
xticks([1:12:Tmonth(end) Tmonth(end)]);
xticklabels(2003:1:2019)
legend({'AMSRE/AMSR2','RAISE'},'Location','northwest','NumColumns',2,'fontsize',12);
set(gca,'linewidth',1.5);
set(gca,'fontsize',15);
title('\bf (g)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';


