% Figure.4 in the manuscript
clc;
clear all;

%% load model info
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
load('..\grid_file\mask_shelf.mat');
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
h=ncread(grdfilename,'h');
zice=ncread(grdfilename,'zice');
pm=ncread(grdfilename,'pm');
pn=ncread(grdfilename,'pn');
grid_area=1./(pm.*pn);

for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end
for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end
end


%% MASK--model
%TNBP
lon_area01=[163,167];  
lat_area01=[-75.75,-74.25];
%RISP
lon_area02=[180,196];   
lat_area02=[-78.6,-77.25];
lon_area03=[166,180];
lat_area03=[-78.5,-76.25];
mask_RISP=zeros(1000,1000);
mask_TNBP=zeros(1000,1000);
for i=1:1000
    for j=1:1000
        if zice(i,j)==0
            if lon_rho(i,j)<=lon_area02(2)&&lon_rho(i,j)>=lon_area02(1)&&lat_rho(i,j)>=lat_area02(1)&&lat_rho(i,j)<=lat_area02(2)
               mask_RISP(i,j)=1;
            end
            if lon_rho(i,j)<=lon_area03(2)&&lon_rho(i,j)>=lon_area03(1)&&lat_rho(i,j)>=lat_area03(1)&&lat_rho(i,j)<=lat_area03(2)
               mask_RISP(i,j)=1;
            end
        end
    end
end
for i=1:1000
    for j=1:1000
        if zice(i,j)==0
            if lon_rho(i,j)<=lon_area01(2)&&lon_rho(i,j)>=lon_area01(1)&&lat_rho(i,j)>=lat_area01(1)&&lat_rho(i,j)<=lat_area01(2)
               mask_TNBP(i,j)=1;
            end
        end
    end
end


figure(2)
m_proj('Equidistant Cylindrical','lat',[-80 -68],'long',[160 220]);    
m_pcolor(lon_rho,lat_rho,mask_TNBP);
colormap([1 1 1;1 0 1]);
caxis([0,1]);
grid on
hold on
m_contour(lon_rho,lat_rho,h,[500,1000,1500],'color','#4F4F4F','linewidth',0.8);
m_text(189,-73,{'Ross Sea'},'color','w','FontSize',16);
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','linest','none','tickdir','in','linewidth',2,'fontsize',12,'xtick',5,'xaxisloc','top','yaxisloc','left');


%% load sea ice production data ---- RAISE
RAS_data_dirname='..\Base_simulation_nudging\';
savedirname='..\GMD_2024\data\Figure-4\';
%-----------------sea ice produciton varition---------------
clc
year_begin=2003;
year_end=2013;

month_begin=6;
month_end=8;
total_day=92;


yearindex=1;
for iyear=year_begin:year_end
    monthindex=1;
    for imonth=month_begin:month_end
        sip_monthly(:,:,monthindex)=GetMonthlyData(iyear,imonth,'iomflx',RAS_data_dirname);
        monthindex=monthindex+1;
    end
    sip_annual=mean(sip_monthly,3).*(total_day*24*60*60);

    sip_RAISE_TNBP(yearindex,1)=sum(sum(sip_annual.*mask_TNBP.*grid_area,'omitnan'))./1e9;
    sip_RAISE_RISP(yearindex,1)=sum(sum(sip_annual.*mask_RISP.*grid_area,'omitnan'))./1e9;

    disp(['SIP in TNBP  (',num2str(iyear),') ',num2str(sip_RAISE_TNBP(yearindex,1)),' km^{3} yr^{-1}']);
    disp(['SIP in RISP  (',num2str(iyear),') ',num2str(sip_RAISE_RISP(yearindex,1)),' km^{3} yr^{-1}']);

    yearindex=yearindex+1;
end
save([savedirname,'sip_RAISE.mat'],'sip_RAISE_TNBP','sip_RAISE_RISP');    


%-----------------sea ice produciton varition---------------
year_begin=2003;
year_end=2010;

month_begin=3;
month_end=10;
total_day=245;

yearindex=1;
for iyear=year_begin:year_end
    monthindex=1;
    for imonth=month_begin:month_end
        sip_monthly(:,:,monthindex)=GetMonthlyData(iyear,imonth,'iomflx',RAS_data_dirname);
        monthindex=monthindex+1;
    end
    sip_annual(:,:,yearindex)=mean(sip_monthly,3).*(total_day*24*60*60);
    yearindex=yearindex+1;
end
sip_2003to2010_RAISE=mean(sip_annual(:,:,1:8),3);

sip_RAISE_TNBP_2003to2010=sum(sum(sip_2003to2010_RAISE.*mask_TNBP.*grid_area,'omitnan'))./1e9;
sip_RAISE_RISP_2003to2010=sum(sum(sip_2003to2010_RAISE.*mask_RISP.*grid_area,'omitnan'))./1e9;

disp(['SIP in TNBP 2003to2010: ',num2str(sip_RAISE_TNBP_2003to2010),' km^{3} yr^{-1}']);
disp(['SIP in RISP 2003to2010: ',num2str(sip_RAISE_RISP_2003to2010),' km^{3} yr^{-1}']);

save([savedirname,'sip_2003to2010_RAISE.mat'],'sip_2003to2010_RAISE');    

%% mask---SSMI
load('..\Model_validation\SIP\SIP_Ohshima_rawdata\SSMI-POLAR\latlon.mat');
load('..\Model_validation\SIP\SIP_Ohshima_rawdata\SSMI-POLAR\landmask.mat');

% TNBP
lon_area01=[163,167];  
lat_area01=[-75.75,-74.25];
mask_TNB=zeros(721,721);
for i=1:721
    for j=1:721
       if lon(i,j)<=lon_area01(2)&&lon(i,j)>=lon_area01(1)&&lat(i,j)>=lat_area01(1)&&lat(i,j)<=lat_area01(2)
          mask_TNB(i,j)=1;
       else 
          mask_TNB(i,j)=nan;
       end
    end
end

% RISP
lon_area02=[180,196];   
lat_area02=[-78.6,-77.25];
lon_area03=[166,180];
lat_area03=[-78.5,-76.25];
mask_RISP=zeros(721,721);
for i=1:721
    for j=1:721
        if lon(i,j)<=lon_area02(2)&&lon(i,j)>=lon_area02(1)&&lat(i,j)>=lat_area02(1)&&lat(i,j)<=lat_area02(2)
           mask_RISP(i,j)=1;
        end
        if lon(i,j)<=lon_area03(2)&&lon(i,j)>=lon_area03(1)&&lat(i,j)>=lat_area03(1)&&lat(i,j)<=lat_area03(2)
           mask_RISP(i,j)=1;
        end
    end
end


%% SSMI
jyear=1;
month_begin=6;
month_end=8;
for iyear=2003:2013
    filename=['..\Model_validation\SIP\SIP_Ohshima_rawdata\SSMI-POLAR\heat_salt_flux_',num2str(iyear),'.data'];
    fid=fopen(filename,'rb');

    data1= fread(fid,'single');
    fclose(fid);
    data=reshape(data1,[721 721 6 12]);

    sip=data(:,:,2:6:72);  %2 --ERA-interim--   5 --NCEP2--
    for i=1:721
      for j=1:721
         for k=1:12
             if sip(i,j,k)<0     
                sip(i,j,k)=NaN;
             end
         end
      end
    end
    % SSM/I Equal Area Scalable Earth-Grid (12.5 km * 12.5 km)
    sip_annual=sum(sip(:,:,month_begin:month_end),3,'omitnan').*landmask.*(12500*12500);

    SIP_TNB=sum(sum(sip_annual.*mask_TNB,'omitnan'),'omitnan');
    disp(['Sea ice production in TNB polynya ',num2str(SIP_TNB./1e9),' km^{3} in ',num2str(iyear)])
    SIP_TNB_yearly(jyear,1)=SIP_TNB;

    SIP_RISP=sum(sum(sip_annual.*mask_RISP,'omitnan'),'omitnan');
    disp(['Sea ice production in RIS polynya ',num2str(SIP_RISP./1e9),' km^{3} in ',num2str(iyear)])
    SIP_RISP_yearly(jyear,1)=SIP_RISP;

    jyear=jyear+1;
end
sip_SSMI_TNBP_yearly=(SIP_TNB_yearly./1e9);
sip_SSMI_RISP_yearly=(SIP_RISP_yearly./1e9);

savedirname='..\GMD_2024\data\Figure-4\';
save([savedirname,'sip_SSMI.mat'],'sip_SSMI_TNBP_yearly','sip_SSMI_RISP_yearly');    


%% 比较RAS模型对产冰量的模拟
load('D:\Sjtu\Article\unpublish\GMD_2024\data\Figure-4\sip_2003to2010_RAISE.mat');
load('D:\Sjtu\Article\unpublish\GMD_2024\data\Figure-4\SIP_2003to2010_AMSR_frazil.mat');
load('D:\Sjtu\Article\unpublish\GMD_2024\data\Figure-4\grid_AMSR_frazil.mat');
load("D:\MATLAB\colormap_xc\MeltwaterColormaps.mat");


set(gcf,'position',[100 100 1050 400])
ha=tight_subplot(1,2,[.1 .06],[.05 .05],[.07 .15]);
%---------------------------------Satellite------------------------------
axes(ha(1));
m_proj('Equidistant Cylindrical','lat',[-79 -70],'long',[160 210]);     
m_pcolor(lon,lat,SIP_2003to2010_AMSR_frazil);
colormap(mycmap);
caxis([4,22]);
hold on
m_text(184,-77.2,{'RISP'},'FontSize',13);
m_text(167,-74.7,{'TNBP'},'FontSize',13);
m_contour(lon_rho,lat_rho,h,[500,1000],'color','#4F4F4F','linewidth',0.2);
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),5,[0.85 0.85 0.85],'filled');
m_gshhs_f('color','k','linewidth',0.8);
m_line([180 180],[-82.92 -77.9],'color',[.85 .85 .85],'linewidth',2);
m_text(169,-78.35,{'Ross Ice Shelf'},'FontSize',11);
m_grid('gridcolor','k','linest','none','tickdir','in','linewidth',2,'fontsize',12);
m_text(176,-70.8,{'\bf Estimate from satellite data'},'FontSize',14);
title('\bf (a)','FontSize',14);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
M=m_shaperead('ne_10m_coastline'); 
for k=1:length(M.ncst)
     if M.ncst{k}(:,1)<0
         M.ncst{k}(:,1)=M.ncst{k}(:,1)+360;
     end
     m_line(M.ncst{k}(:,1),M.ncst{k}(:,2),'color','k','linewi',0.8); 
end

%-------------------------------RAISE------------------------------
axes(ha(2));
m_proj('Equidistant Cylindrical','lat',[-79 -70],'long',[160 210]);    
m_pcolor(lon_rho,lat_rho,sip_2003to2010_RAISE);
m_grid('gridcolor','k','linest','none','tickdir','in','linewidth',2,'fontsize',12);
colormap(mycmap);
caxis([4,22]);
hold on
m_text(184,-77.2,{'RISP'},'FontSize',13);
m_text(167,-74.7,{'TNBP'},'FontSize',13);
m_contour(lon_rho,lat_rho,h,[500,1000],'color','#4F4F4F','linewidth',0.2);
m_scatter(mask_iceshelf(:,1),mask_iceshelf(:,2),5,[0.85 0.85 0.85],'filled');
m_gshhs_f('color','k','linewidth',0.8);
m_line([180 180],[-82.92 -77.9],'color',[.85 .85 .85],'linewidth',2);
m_text(169,-78.35,{'Ross Ice Shelf'},'FontSize',11);
m_grid('gridcolor','k','linest','none','tickdir','in','linewidth',2,'fontsize',12);
m_text(196,-70.8,{'\bf RAISE'},'FontSize',14);
title('\bf (b)','FontSize',14);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
M=m_shaperead('ne_10m_coastline'); 
for k=1:length(M.ncst)
     if M.ncst{k}(:,1)<0
         M.ncst{k}(:,1)=M.ncst{k}(:,1)+360;
     end
     m_line(M.ncst{k}(:,1),M.ncst{k}(:,2),'color','k','linewi',0.8); 
end

ch=colorbar('eastoutside','fontsize',12);
set(get(ch,'label'),'string','Sea ice production [m yr^{-1}]','fontsize',12);
pos3=set(ch,'Position', [0.885,0.26,0.012,0.46]);


%% scatter figure
load('D:\Sjtu\Article\unpublish\GMD_2024\data\Figure-4\sip_RAISE.mat');
load('D:\Sjtu\Article\unpublish\GMD_2024\data\Figure-4\sip_SSMI.mat');


figure(2)
set(gcf,'position',[180 180 920 400])
ha=tight_subplot(1,2,[.05 .07],[.2 .12],[.07 .05]);
axes(ha(1));
[R1,P1]=corrcoef(sip_RAISE_TNBP,sip_SSMI_TNBP_yearly);

input=[ones(size(sip_RAISE_TNBP)) sip_RAISE_TNBP];
[b,bint,r,rint,stats]=regress(sip_SSMI_TNBP_yearly,input);

scatter(sip_RAISE_TNBP,sip_SSMI_TNBP_yearly,75,[165 165 165]./255,'filled');
xlim([20,50])
xlabel('RAISE SIP [km^{3}]');
ylim([0,43])
ylabel('SSMI SIP [km^{3}]');
text(35,5,['\bf R=',num2str(R1(1,2),'%.2f'),', P=',...
    num2str(P1(1,2),'%.2f')],'fontsize',15,'color','k');
title('\bf (c)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
grid on
box on
hold on
text(22,38,'\bf TNBP','fontsize',16,'color','k');
regress_x=20:2:50;
regress_y=regress_x.*b(2)+b(1);
plot(regress_x,regress_y,'--k','LineWidth',1.5);
set(gca,'FontName','SansSarif');
set(gca,'Fontsize',12); 
set(gca,'linewidth',2)


axes(ha(2));
[R2,P2]=corrcoef(sip_RAISE_RISP,sip_SSMI_RISP_yearly);

input=[ones(size(sip_RAISE_RISP)) sip_RAISE_RISP];
[b,bint,r,rint,stats]=regress(sip_SSMI_RISP_yearly,input);

scatter(sip_RAISE_RISP,sip_SSMI_RISP_yearly,75,[165 165 165]./255,'filled');
xlim([100,400])
xlabel('RAISE SIP [km^{3}]');
ylim([0,180])
ylabel('SSMI SIP  [km^{3}]');
text(257,21,['\bf R=',num2str(R2(1,2),'%.2f'),', P=',...
    num2str(P2(1,2),'%.2f')],'fontsize',15,'color','k');
title('\bf (d)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
grid on
box on
hold on
text(120,160,'\bf RISP','fontsize',16,'color','k');
regress_x=100:2:400;
regress_y=regress_x.*b(2)+b(1);
% regress_y_idea=regress_x.*1;
plot(regress_x,regress_y,'--k','LineWidth',1.5);
% plot(regress_x,regress_y_idea,'--k','LineWidth',1.5);
set(gca,'FontName','SansSarif');
set(gca,'Fontsize',12); 
set(gca,'linewidth',2)

