% Figure.6 in the manuscript
clc
clear all

%% --------------------MEOP-CTD data---------------------
% ncdisp('ct64-M053-09_interp_prof.nc')
filename=['..\Model_validation\temp_salt\MEOP-CTD' ...
    '\AUSTRALIA\DATA_ncARGO_interp\ct64-M053-09_interp_prof.nc'];
LAT_meop=ncread(filename,'LATITUDE');
LONG_meop=ncread(filename,'LONGITUDE');
PRES=ncread(filename,'PRES_ADJUSTED');
TEMP=ncread(filename,'TEMP_ADJUSTED');
PSAL=ncread(filename,'PSAL_ADJUSTED');
TIME=ncread(filename,'JULD');
GAMMA=gamma_GP_from_SP_pt(PSAL,TEMP,PRES,LONG_meop,LAT_meop);

section_location=165:210;   %time：03/10/2010-03/25/2010
[~,station_num]=size(section_location);
figure(1)
m_proj('Equidistant Cylindrical','lat',[-80 -63],'long',[150 220]);     
m_etopo2('contourf',[-5000:500:-500 -500:100:-200 -200:50:0],'edgecolor','none');
m_gshhs_f('patch',[.8 .8 .8],'linewidth',2,'edgecolor','k');
m_line([180 180],[-84 -77.9],'color',[.8 .8 .8],'linewidth',2);
m_grid('gridcolor','k','tickdir','in','linewidth',3,'fontsize',12);
colormap(m_colmap('blues'));
h=colorbar;
set(get(h,'label'),'string','Depth [m]','fontsize',12);
hold on
m_scatter(LONG_meop(section_location,1),LAT_meop(section_location,1),20,'r','filled');

%-----------------------------------load model grid---------------------------------
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
load('..\grid_file\RAS_depth.mat');
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
mask_rho=ncread(grdfilename,'mask_rho');
%Calculates sea pressure from depth 
for k=1:32
   pr(:,:,k) = gsw_p_from_z(zr(:,:,k),lat_rho);
end

%---------------------------load data from model simulation--------------------------
RAS_data_dirname='..\Base_simulation_nudging\';
filename=[RAS_data_dirname,'RAS_avg_0090.nc'];
temp=ncread(filename,'temp');
salt=ncread(filename,'salt');
temp_model=mean(temp(:,:,:,1:2),4); 
salt_model=mean(salt(:,:,:,1:2),4);
for k=1:32
   gamma_model(:,:,k)=gamma_GP_from_SP_pt(salt_model(:,:,k),temp_model(:,:,k),pr(:,:,k),lon_rho,lat_rho);
end

for i=1:station_num  
   ij=section_location(1,i);
   lon_0=LONG_meop(ij,1); 
   lat_0=LAT_meop(ij,1); 
   diff_lon=lon_rho-lon_0;
   diff_lat=lat_rho-lat_0;
   for ii=1:1000
       for jj=1:1000
            if abs(diff_lon(ii,jj))>1||abs(diff_lat(ii,jj))>1
                 dis(ii,jj)=10000;
            else
                 dis(ii,jj)=distance(lat_rho(ii,jj),lon_rho(ii,jj),lat_0,lon_0);
            end
       end
   end
   disp(i)
   [M,I]=find(dis==min(min(dis)));
   salt_RAS_profile(:,i)=salt_model(M,I,:);
   temp_RAS_profile(:,i)=temp_model(M,I,:);
   gamma_RAS_profile(:,i)=gamma_model(M,I,:);
   depth_RAS_profile(:,i)=zr(M,I,:);
end

%% TS section profile comparsion
contour_gammamin=27.6;
contour_gammainterval=0.3;
contour_gammamax=28.6;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%---------------------Potential Temperature--------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(3)
set(gcf,'position',[30 10 450 650])
ha=tight_subplot(2,1,[.06 .02],[.23 .06],[.14 .06]);
load('D:\MATLAB\NCL_colormap\cmocean_thermal.rgb');
axes(ha(1));
LAT_plot=repmat(LAT_meop,1,1000)';          
pcolor(LAT_plot(:,section_location),-PRES(:,section_location),TEMP(:,section_location));
shading interp
hold on
% contour(LAT_plot(:,section_location),-PRES(:,section_location),TEMP(:,section_location),...
%     [-0.5,0.5],'color','#000000','linewidth',1.2,'ShowText','on');
contour(LAT_plot(:,section_location),-PRES(:,section_location),GAMMA(:,section_location),...
    [contour_gammamin:contour_gammainterval:contour_gammamax],...
    'color','#d4d4d4','linewidth',1.4,'ShowText','on');
caxis([-2.5 2.5]);
ylim([-600 0]);
ylabel('Depth [m]','FontSize',14);
colormap(cmocean_thermal./255);
xticks([-76:1:-71]);
xticklabels({' ',' ',' ',' ',' ',' ',' '});
text(-76,-500,'\bf MEOP','FontSize',15);
title('\bf (a)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',1.6)

axes(ha(2));
LAT_plot=repmat(LAT_meop,1,32)';
pcolor(LAT_plot(:,section_location),depth_RAS_profile,temp_RAS_profile);
shading interp
hold on
% contour(LAT_plot(:,section_location),depth_RAS_profile,temp_RAS_profile,[-0.5,0.5],...
%     'color','#000000','linewidth',1.2,'ShowText','on');
contour(LAT_plot(:,section_location),depth_RAS_profile,gamma_RAS_profile,...
    [contour_gammamin:contour_gammainterval:contour_gammamax],...
    'color','#d4d4d4','linewidth',1.4,'ShowText','on');
caxis([-2.5 2.5]);
ylim([-600 0]);
ylabel('Depth [m]','FontSize',14);
colormap(cmocean_thermal./255);
xticks([-76:1:-71]); 
xticklabels({'76\circS','75\circS','74\circS','73\circS','72\circS','71\circS','70\circS'})
text(-76,-500,'\bf RAISE','FontSize',15);
title('\bf (c)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',1.6)

h=colorbar('southoutside','fontsize',12);
set(get(h,'Title'),'string','Potential Temperature [\circC]','fontsize',12);
set(h,'Position', [0.17,0.12,0.72,0.014]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%---------------------------salinity--------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load('D:\MATLAB\NCL_colormap\cmocean_haline.rgb');
figure(4)
set(gcf,'position',[30 10 450 650])
ha=tight_subplot(2,1,[.06 .02],[.23 .06],[.1 .06]);
axes(ha(1));
LAT_plot=repmat(LAT_meop,1,1000)';
pcolor(LAT_plot(:,section_location),-PRES(:,section_location),PSAL(:,section_location));
hold on
% contour(LAT_plot(:,section_location),-PRES(:,section_location),PSAL(:,section_location), ...
%        [33.8,34.4,34.6],...
%     'color','#d4d4d4','linewidth',1.2,'ShowText','on');
contour(LAT_plot(:,section_location),-PRES(:,section_location),GAMMA(:,section_location), ...
       [contour_gammamin:contour_gammainterval:contour_gammamax],...
    'color','#d4d4d4','linewidth',1.4,'ShowText','on');
shading interp
caxis([33.6 34.8]);
ylim([-600 0]);
colormap(cmocean_haline./255)
xticks([-76:1:-71]);
xticklabels({' ',' ',' ',' ',' ',' ',' '});
text(-76,-500,'\bf MEOP','FontSize',15);
title('\bf (b)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',1.6)

axes(ha(2));
LAT_plot=repmat(LAT_meop,1,32)';
pcolor(LAT_plot(:,section_location),depth_RAS_profile,salt_RAS_profile);
shading interp 
colormap(cmocean_haline./255)
hold on
% contour(LAT_plot(:,section_location),depth_RAS_profile,salt_RAS_profile,[33.8,34.4,34.6],...
%     'color','#d4d4d4','linewidth',1.2,'ShowText','on');
contour(LAT_plot(:,section_location),depth_RAS_profile,gamma_RAS_profile,...
    [contour_gammamin:contour_gammainterval:contour_gammamax],...
    'color','#d4d4d4','linewidth',1.4,'ShowText','on');
caxis([33.6 34.8]);
ylim([-600 0]);
xticks([-76:1:-71]);
xticklabels({'76\circS','75\circS','74\circS','73\circS','72\circS','71\circS','70\circS'})
text(-76,-500,'\bf RAISE','FontSize',15);
title('\bf (d)','fontsize',12);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
set(gca,'linewidth',1.6)

h=colorbar('southoutside','fontsize',12);
set(get(h,'Title'),'string','Salinity [PSU]','fontsize',12);
set(h,'Position', [0.17,0.12,0.72,0.014]);


