% Figure.8 in the manuscript

clc
clear all

%% load grid information from RAS model grid file 
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
load('..\grid_file\RAS_depth.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
zice=ncread(grdfilename,'zice');
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
pm=ncread(grdfilename,'pm');
pn=ncread(grdfilename,'pn');
mask_rho=ncread(grdfilename,'mask_rho');
ang=ncread(grdfilename,'angle');
h=ncread(grdfilename,'h');
for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end

for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end
end
grid_area=(1./pm).*(1./pn);
dz=zw(:,:,2:end)-zw(:,:,1:end-1);

%% load data
dye_01=ncread('..\tracer_experiment\RAS_avg_0073.nc','dye_01');
CDW_dye=dye_01(:,:,:,end);
dye_03=ncread('..\tracer_experiment\RAS_avg_0073.nc','dye_03');
ISW_Amundsen_dye=dye_03(:,:,:,end);
dye_02=ncread('..\tracer_experiment\RAS_avg_0073.nc','dye_02');
ISW_Ross_dye=dye_02(:,:,:,end);


%% CDW_ISW dye
load("..\NCL_colormap\WhiteBlueGreenYellowRed.rgb");

figure(1)
set(gcf,'Position',[300 60 1050 750]);
ha=tight_subplot(2, 2, [.08 .02], [.06 .04], [.05 .01]);

axes(ha(1));
m_proj('Equidistant Cylindrical','lat',[-85.5 -67],'long',[159 268.5]);      
m_pcolor(lon_rho,lat_rho,sum(ISW_Ross_dye,3).*grid_area./1e6);
colormap(WhiteBlueGreenYellowRed./255);
caxis([0,9000]);
title('\bf(a)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
m_contour(lon_rho,lat_rho,h,[500,1000,2000],'color','#4F4F4F','linewidth',0.5);
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','linest','none','linewidth',2,...
    'fontsize',12,'xtick',6,'yaxisloc','left');


axes(ha(2));
m_proj('Equidistant Cylindrical','lat',[-85.5 -67],'long',[159 268.5]);      
m_pcolor(lon_rho,lat_rho,sum(ISW_Amundsen_dye,3).*grid_area./1e6);
colormap(WhiteBlueGreenYellowRed./255);
caxis([0,9000]);
title('\bf(b)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
m_contour(lon_rho,lat_rho,h,[500,1000,2000],'color','#4F4F4F','linewidth',0.5);
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','linest','none','linewidth',2,...
    'fontsize',12,'xtick',6,'yaxisloc','left');

ch=colorbar('southoutside','fontsize',11);
set(get(ch,'label'),'string','ISW tracer unit','fontsize',11) 
set(ch,'Position', [0.3005,0.628,0.1605,0.0153]);  

ch=colorbar('southoutside','fontsize',11);
set(get(ch,'label'),'string','ISW tracer unit','fontsize',11) 
set(ch,'Position', [0.7805,0.628,0.1605,0.0153]);  

% plot CDW dye
CDWdye_max=30;
CDWdye_min=16;

axes(ha(3));
m_proj('Equidistant Cylindrical','lat',[-85.5 -67],'long',[159 268.5]);      
m_pcolor(lon_rho,lat_rho,CDW_dye(:,:,15).*100);
colormap(WhiteBlueGreenYellowRed./255);
caxis([20,80]);
title('\bf (c)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
m_contour(lon_rho,lat_rho,h,[500,1000,2000],'color','#4F4F4F','linewidth',0.5);
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2,'k','filled');
m_scatter(land_line(:,1),land_line(:,2),2,'k','filled');
m_grid('gridcolor','k','linest','none','linewidth',2,...
    'fontsize',12,'xtick',6,'yaxisloc','left');

%-----total colorbar-------
ch=colorbar('southoutside','fontsize',11);
set(get(ch,'label'),'string','CDW tracer unit','fontsize',11) 
set(ch,'Position', [0.317,0.150,0.1228,0.017]);  


