% Figure.9 in the manuscript
clc
clear all
%% load grid information from RAS model grid file 
load('..\grid_file\ice_shelf\iceshelf_land_line_and_mask.mat');
load('..\grid_file\RAS_depth.mat');
grdfilename='..\grid_file\RAS_grd_32layer_new.nc';
zice=ncread(grdfilename,'zice');
lon_rho=ncread(grdfilename,'lon_rho');
lat_rho=ncread(grdfilename,'lat_rho');
pm=ncread(grdfilename,'pm');
pn=ncread(grdfilename,'pn');
mask_rho=ncread(grdfilename,'mask_rho');
ang=ncread(grdfilename,'angle');
h=ncread(grdfilename,'h');
for i=1:1000
    for j=1:1000
        if lon_rho(i,j)<0
            lon_rho(i,j)=lon_rho(i,j)+360;
        end
    end
end

for i=1:1000
    for j=1:1000
        if mask_rho(i,j)==0
            h(i,j)=NaN;
        end
    end
end
grid_area=(1./pm).*(1./pn);
dz=zw(:,:,2:end)-zw(:,:,1:end-1);

%% load data
dye_02=ncread('..\tracer_experiment\RAS_avg_0073.nc','dye_02');
DSW_TNBP_dye=dye_02(:,:,:,end);
dye_04=ncread('..\tracer_experiment\RAS_avg_0073.nc','dye_04');
DSW_RISP_dye=dye_04(:,:,:,end);

DSW_TNBP_dye_bottom=DSW_TNBP_dye;
DSW_RISP_dye_bottom=DSW_RISP_dye;
Depth_thershod_min=-300;
depth_bottom_mask=ones(1000,1000,32);
for i=1:1000
    for j=1:1000
       for k=1:32
          if zr(i,j,k)>Depth_thershod_min
                DSW_TNBP_dye_bottom(i,j,k)=NaN;
                DSW_RISP_dye_bottom(i,j,k)=NaN;
                depth_bottom_mask(i,j,k)=0;
          end
       end
    end
end

depth_bottom=sum(depth_bottom_mask.*dz,3);
DSW_TNBP_dye_bottomlayer=sum(DSW_TNBP_dye_bottom(:,:,:).*depth_bottom_mask.*dz,3,'omitnan').*grid_area;
DSW_RISP_dye_bottomlayer=sum(DSW_RISP_dye_bottom(:,:,:).*depth_bottom_mask.*dz,3,'omitnan').*grid_area;

save('..\GMD_2024\data\Figure-9\DSW_dye.mat',...
    'DSW_TNBP_dye','DSW_RISP_dye','DSW_RISP_dye_bottomlayer','DSW_TNBP_dye_bottomlayer');


%% DSW dye
load('..\GMD_2024\data\Figure-9\DSW_dye.mat');
%-------DT------
xi_rho_index=180:195;
eta_rho_index=475;
section01_lon=lon_rho(xi_rho_index,eta_rho_index);
section01_lat=lat_rho(xi_rho_index,eta_rho_index);

%-------JT------
xi_rho_index=230:245;
eta_rho_index=425;
section02_lon=lon_rho(xi_rho_index,eta_rho_index);
section02_lat=lat_rho(xi_rho_index,eta_rho_index);

%-------GCT------
xi_rho_index=305:335;
eta_rho_index=350;
section03_lon=lon_rho(xi_rho_index,eta_rho_index);
section03_lat=lat_rho(xi_rho_index,eta_rho_index);


load("..\NCL_colormap\precip3_16lev.rgb");

figure(1)
set(gcf,'Position',[300 160 800 650]);
ha=tight_subplot(1, 2, [.01 .015], [.18 .04], [.08 .01]);
axes(ha(1));
m_proj('Equidistant Cylindrical','lat',[-85.5 -66],'long',[159 212]);      
m_pcolor(lon_rho,lat_rho,DSW_TNBP_dye_bottomlayer./1e8);
colormap(precip3_16lev./255);
caxis([0,800]);
title('\bf(a)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
m_scatter(section01_lon,section01_lat,10,'k','filled');
m_scatter(section02_lon,section02_lat,10,'k','filled');
m_scatter(section03_lon,section03_lat,10,'k','filled');
m_text(171,-72.6,{'\bfDT'},'color','k','FontSize',10);
m_text(175,-73.8,{'\bfJT'},'color','k','FontSize',10);
m_text(182,-75.9,{'\bfGCT'},'color','k','FontSize',10);
m_contour(lon_rho,lat_rho,h,[500,1000,2000],'color','#4F4F4F','linewidth',0.5);
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2.5,'k','filled');
m_scatter(land_line(:,1),land_line(:,2),2.5,'k','filled');
m_grid('gridcolor','k','linest','none','linewidth',2,...
    'fontsize',12,'xtick',5,'yaxisloc','left');
m_text(195,-68,'\bf TNBP','color','k','fontsize',18);

ch=colorbar('southoutside','fontsize',12);       
set(get(ch,'label'),'string','DSW dye unit','fontsize',12) 
set(ch,'Position', [0.14,0.11,0.3,0.018]);  

axes(ha(2));
m_proj('Equidistant Cylindrical','lat',[-85.5 -66],'long',[159 212]);      
m_pcolor(lon_rho,lat_rho,DSW_RISP_dye_bottomlayer./1e8);
colormap(precip3_16lev./255);
caxis([0,3500]);
title('\bf(b)','fontsize',13);
ax = gca;
ax.TitleHorizontalAlignment = 'left';
hold on
m_scatter(section01_lon,section01_lat,10,'k','filled');
m_scatter(section02_lon,section02_lat,10,'k','filled');
m_scatter(section03_lon,section03_lat,10,'k','filled');
m_text(171,-72.6,{'\bfDT'},'color','k','FontSize',10);
m_text(175,-73.8,{'\bfJT'},'color','k','FontSize',10);
m_text(182,-75.9,{'\bfGCT'},'color','k','FontSize',10);
m_contour(lon_rho,lat_rho,h,[500,1000,2000],'color','#4F4F4F','linewidth',0.5);
m_scatter(iceshelf_line(:,1),iceshelf_line(:,2),2.5,'k','filled');
m_scatter(land_line(:,1),land_line(:,2),2.5,'k','filled');
m_grid('gridcolor','k','linest','none','linewidth',2,...
    'fontsize',12,'xtick',5,'yaxisloc','left','yticklabels',[]);
m_text(195,-68,'\bf RISP','color','k','fontsize',18);

ch=colorbar('southoutside','fontsize',12);
set(get(ch,'label'),'string','DSW dye unit','fontsize',12) 
set(ch,'Position', [0.61,0.11,0.3,0.018]);  


